/****************************************************************************
** Meta object code from reading C++ file 'sagesession.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/cantor-17.08.3/src/backends/sage/sagesession.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sagesession.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_SageSession_t {
    QByteArrayData data[16];
    char stringdata0[222];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SageSession_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SageSession_t qt_meta_stringdata_SageSession = {
    {
QT_MOC_LITERAL(0, 0, 11), // "SageSession"
QT_MOC_LITERAL(1, 12, 10), // "readStdOut"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 10), // "readStdErr"
QT_MOC_LITERAL(4, 35, 30), // "currentExpressionChangedStatus"
QT_MOC_LITERAL(5, 66, 26), // "Cantor::Expression::Status"
QT_MOC_LITERAL(6, 93, 6), // "status"
QT_MOC_LITERAL(7, 100, 15), // "processFinished"
QT_MOC_LITERAL(8, 116, 8), // "exitCode"
QT_MOC_LITERAL(9, 125, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(10, 146, 10), // "exitStatus"
QT_MOC_LITERAL(11, 157, 18), // "reportProcessError"
QT_MOC_LITERAL(12, 176, 22), // "QProcess::ProcessError"
QT_MOC_LITERAL(13, 199, 5), // "error"
QT_MOC_LITERAL(14, 205, 11), // "fileCreated"
QT_MOC_LITERAL(15, 217, 4) // "path"

    },
    "SageSession\0readStdOut\0\0readStdErr\0"
    "currentExpressionChangedStatus\0"
    "Cantor::Expression::Status\0status\0"
    "processFinished\0exitCode\0QProcess::ExitStatus\0"
    "exitStatus\0reportProcessError\0"
    "QProcess::ProcessError\0error\0fileCreated\0"
    "path"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SageSession[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x0a /* Public */,
       3,    0,   45,    2, 0x0a /* Public */,
       4,    1,   46,    2, 0x08 /* Private */,
       7,    2,   49,    2, 0x08 /* Private */,
      11,    1,   54,    2, 0x08 /* Private */,
      14,    1,   57,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 9,    8,   10,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, QMetaType::QString,   15,

       0        // eod
};

void SageSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SageSession *_t = static_cast<SageSession *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->readStdOut(); break;
        case 1: _t->readStdErr(); break;
        case 2: _t->currentExpressionChangedStatus((*reinterpret_cast< Cantor::Expression::Status(*)>(_a[1]))); break;
        case 3: _t->processFinished((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        case 4: _t->reportProcessError((*reinterpret_cast< QProcess::ProcessError(*)>(_a[1]))); break;
        case 5: _t->fileCreated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject SageSession::staticMetaObject = {
    { &Cantor::Session::staticMetaObject, qt_meta_stringdata_SageSession.data,
      qt_meta_data_SageSession,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *SageSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SageSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SageSession.stringdata0))
        return static_cast<void*>(this);
    return Cantor::Session::qt_metacast(_clname);
}

int SageSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Cantor::Session::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
