#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <keditlistwidget.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_MaximaSettingsBase
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    KUrlRequester *kcfg_Path;
    QCheckBox *kcfg_integratePlots;
    QCheckBox *kcfg_variableManagement;
    QGroupBox *kcfg_scriptGroup;
    QVBoxLayout *verticalLayoutScripts;
    KEditListWidget *kcfg_autorunScripts;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *MaximaSettingsBase)
    {
        if (MaximaSettingsBase->objectName().isEmpty())
            MaximaSettingsBase->setObjectName(QStringLiteral("MaximaSettingsBase"));
        MaximaSettingsBase->resize(414, 231);
        verticalLayout = new QVBoxLayout(MaximaSettingsBase);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label = new QLabel(MaximaSettingsBase);
        label->setObjectName(QStringLiteral("label"));

        horizontalLayout->addWidget(label);

        kcfg_Path = new KUrlRequester(MaximaSettingsBase);
        kcfg_Path->setObjectName(QStringLiteral("kcfg_Path"));

        horizontalLayout->addWidget(kcfg_Path);


        verticalLayout->addLayout(horizontalLayout);

        kcfg_integratePlots = new QCheckBox(MaximaSettingsBase);
        kcfg_integratePlots->setObjectName(QStringLiteral("kcfg_integratePlots"));

        verticalLayout->addWidget(kcfg_integratePlots);

        kcfg_variableManagement = new QCheckBox(MaximaSettingsBase);
        kcfg_variableManagement->setObjectName(QStringLiteral("kcfg_variableManagement"));

        verticalLayout->addWidget(kcfg_variableManagement);

        kcfg_scriptGroup = new QGroupBox(MaximaSettingsBase);
        kcfg_scriptGroup->setObjectName(QStringLiteral("kcfg_scriptGroup"));
        verticalLayoutScripts = new QVBoxLayout(kcfg_scriptGroup);
        verticalLayoutScripts->setObjectName(QStringLiteral("verticalLayoutScripts"));
        kcfg_autorunScripts = new KEditListWidget(kcfg_scriptGroup);
        kcfg_autorunScripts->setObjectName(QStringLiteral("kcfg_autorunScripts"));

        verticalLayoutScripts->addWidget(kcfg_autorunScripts);


        verticalLayout->addWidget(kcfg_scriptGroup);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(MaximaSettingsBase);

        QMetaObject::connectSlotsByName(MaximaSettingsBase);
    } // setupUi

    void retranslateUi(QWidget *MaximaSettingsBase)
    {
        label->setText(tr2i18n("Path to Maxima:", Q_NULLPTR));
        kcfg_integratePlots->setText(tr2i18n("Integrate Plots in Worksheet", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        kcfg_variableManagement->setToolTip(tr2i18n("Let Cantor follow the creation/destruction of variables", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        kcfg_variableManagement->setText(tr2i18n("Enable Variable Management", Q_NULLPTR));
        kcfg_scriptGroup->setTitle(tr2i18n("Scripts to autorun", Q_NULLPTR));
        Q_UNUSED(MaximaSettingsBase);
    } // retranslateUi

};

namespace Ui {
    class MaximaSettingsBase: public Ui_MaximaSettingsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

