#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <keditlistwidget.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_QalculateSettingsBase
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *qtabwidget;
    QWidget *tab_3;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *kcfg_base;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_5;
    KComboBox *kcfg_fractionFormat;
    QHBoxLayout *horizontalLayout_9;
    QLabel *label_9;
    KComboBox *kcfg_minExp;
    QHBoxLayout *horizontalLayout_6;
    QLabel *label_6;
    QCheckBox *kcfg_indicateInfiniteSeries;
    QHBoxLayout *horizontalLayout_7;
    QLabel *label_7;
    QCheckBox *kcfg_useAllPrefixes;
    QHBoxLayout *horizontalLayout_8;
    QLabel *label_8;
    QCheckBox *kcfg_negativeExponents;
    QGroupBox *kcfg_scriptGroup;
    QVBoxLayout *verticalLayoutScripts;
    KEditListWidget *kcfg_autorunScripts;
    QSpacerItem *verticalSpacer;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QCheckBox *kcfg_postConversion;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_3;
    KComboBox *kcfg_angleUnit;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_4;
    KComboBox *kcfg_structuring;
    QSpacerItem *verticalSpacer_2;
    QWidget *tab;
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout_10;
    QLabel *label_10;
    QCheckBox *kcfg_inlinePlot;
    QHBoxLayout *horizontalLayout_15;
    QLabel *label_15;
    QCheckBox *kcfg_coloredPlot;
    QHBoxLayout *horizontalLayout_11;
    QLabel *label_11;
    QCheckBox *kcfg_plotGrid;
    QHBoxLayout *horizontalLayout_12;
    QLabel *label_12;
    QCheckBox *kcfg_plotBorder;
    QHBoxLayout *horizontalLayout_17;
    QLabel *label_17;
    QSpinBox *kcfg_plotLineWidth;
    QHBoxLayout *horizontalLayout_18;
    QLabel *label_18;
    QSpinBox *kcfg_plotSteps;
    QHBoxLayout *horizontalLayout_13;
    QLabel *label_13;
    KComboBox *kcfg_plotSmoothing;
    QHBoxLayout *horizontalLayout_14;
    QLabel *label_14;
    KComboBox *kcfg_plotStyle;
    QHBoxLayout *horizontalLayout_16;
    QLabel *label_16;
    KComboBox *kcfg_plotLegend;
    QSpacerItem *verticalSpacer_3;

    void setupUi(QWidget *QalculateSettingsBase)
    {
        if (QalculateSettingsBase->objectName().isEmpty())
            QalculateSettingsBase->setObjectName(QStringLiteral("QalculateSettingsBase"));
        QalculateSettingsBase->resize(420, 327);
        verticalLayout = new QVBoxLayout(QalculateSettingsBase);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        qtabwidget = new QTabWidget(QalculateSettingsBase);
        qtabwidget->setObjectName(QStringLiteral("qtabwidget"));
        tab_3 = new QWidget();
        tab_3->setObjectName(QStringLiteral("tab_3"));
        verticalLayout_2 = new QVBoxLayout(tab_3);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label = new QLabel(tab_3);
        label->setObjectName(QStringLiteral("label"));
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(label);

        kcfg_base = new QSpinBox(tab_3);
        kcfg_base->setObjectName(QStringLiteral("kcfg_base"));

        horizontalLayout->addWidget(kcfg_base);


        verticalLayout_2->addLayout(horizontalLayout);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QStringLiteral("horizontalLayout_5"));
        label_5 = new QLabel(tab_3);
        label_5->setObjectName(QStringLiteral("label_5"));
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_5->addWidget(label_5);

        kcfg_fractionFormat = new KComboBox(tab_3);
        kcfg_fractionFormat->setObjectName(QStringLiteral("kcfg_fractionFormat"));

        horizontalLayout_5->addWidget(kcfg_fractionFormat);


        verticalLayout_2->addLayout(horizontalLayout_5);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName(QStringLiteral("horizontalLayout_9"));
        label_9 = new QLabel(tab_3);
        label_9->setObjectName(QStringLiteral("label_9"));
        label_9->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_9->addWidget(label_9);

        kcfg_minExp = new KComboBox(tab_3);
        kcfg_minExp->setObjectName(QStringLiteral("kcfg_minExp"));

        horizontalLayout_9->addWidget(kcfg_minExp);


        verticalLayout_2->addLayout(horizontalLayout_9);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QStringLiteral("horizontalLayout_6"));
        label_6 = new QLabel(tab_3);
        label_6->setObjectName(QStringLiteral("label_6"));
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_6->addWidget(label_6);

        kcfg_indicateInfiniteSeries = new QCheckBox(tab_3);
        kcfg_indicateInfiniteSeries->setObjectName(QStringLiteral("kcfg_indicateInfiniteSeries"));

        horizontalLayout_6->addWidget(kcfg_indicateInfiniteSeries);


        verticalLayout_2->addLayout(horizontalLayout_6);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName(QStringLiteral("horizontalLayout_7"));
        label_7 = new QLabel(tab_3);
        label_7->setObjectName(QStringLiteral("label_7"));
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_7->addWidget(label_7);

        kcfg_useAllPrefixes = new QCheckBox(tab_3);
        kcfg_useAllPrefixes->setObjectName(QStringLiteral("kcfg_useAllPrefixes"));

        horizontalLayout_7->addWidget(kcfg_useAllPrefixes);


        verticalLayout_2->addLayout(horizontalLayout_7);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName(QStringLiteral("horizontalLayout_8"));
        label_8 = new QLabel(tab_3);
        label_8->setObjectName(QStringLiteral("label_8"));
        label_8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_8->addWidget(label_8);

        kcfg_negativeExponents = new QCheckBox(tab_3);
        kcfg_negativeExponents->setObjectName(QStringLiteral("kcfg_negativeExponents"));

        horizontalLayout_8->addWidget(kcfg_negativeExponents);


        verticalLayout_2->addLayout(horizontalLayout_8);

        kcfg_scriptGroup = new QGroupBox(tab_3);
        kcfg_scriptGroup->setObjectName(QStringLiteral("kcfg_scriptGroup"));
        verticalLayoutScripts = new QVBoxLayout(kcfg_scriptGroup);
        verticalLayoutScripts->setObjectName(QStringLiteral("verticalLayoutScripts"));
        kcfg_autorunScripts = new KEditListWidget(kcfg_scriptGroup);
        kcfg_autorunScripts->setObjectName(QStringLiteral("kcfg_autorunScripts"));

        verticalLayoutScripts->addWidget(kcfg_autorunScripts);


        verticalLayout_2->addWidget(kcfg_scriptGroup);

        verticalSpacer = new QSpacerItem(20, 102, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        qtabwidget->addTab(tab_3, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName(QStringLiteral("tab_2"));
        verticalLayout_3 = new QVBoxLayout(tab_2);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        label_2 = new QLabel(tab_2);
        label_2->setObjectName(QStringLiteral("label_2"));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_2->addWidget(label_2);

        kcfg_postConversion = new QCheckBox(tab_2);
        kcfg_postConversion->setObjectName(QStringLiteral("kcfg_postConversion"));

        horizontalLayout_2->addWidget(kcfg_postConversion);


        verticalLayout_3->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        label_3 = new QLabel(tab_2);
        label_3->setObjectName(QStringLiteral("label_3"));
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_3->addWidget(label_3);

        kcfg_angleUnit = new KComboBox(tab_2);
        kcfg_angleUnit->setObjectName(QStringLiteral("kcfg_angleUnit"));

        horizontalLayout_3->addWidget(kcfg_angleUnit);


        verticalLayout_3->addLayout(horizontalLayout_3);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        label_4 = new QLabel(tab_2);
        label_4->setObjectName(QStringLiteral("label_4"));
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_4->addWidget(label_4);

        kcfg_structuring = new KComboBox(tab_2);
        kcfg_structuring->setObjectName(QStringLiteral("kcfg_structuring"));

        horizontalLayout_4->addWidget(kcfg_structuring);


        verticalLayout_3->addLayout(horizontalLayout_4);

        verticalSpacer_2 = new QSpacerItem(20, 185, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_2);

        qtabwidget->addTab(tab_2, QString());
        tab = new QWidget();
        tab->setObjectName(QStringLiteral("tab"));
        verticalLayout_4 = new QVBoxLayout(tab);
        verticalLayout_4->setObjectName(QStringLiteral("verticalLayout_4"));
        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName(QStringLiteral("horizontalLayout_10"));
        label_10 = new QLabel(tab);
        label_10->setObjectName(QStringLiteral("label_10"));
        label_10->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_10->addWidget(label_10);

        kcfg_inlinePlot = new QCheckBox(tab);
        kcfg_inlinePlot->setObjectName(QStringLiteral("kcfg_inlinePlot"));

        horizontalLayout_10->addWidget(kcfg_inlinePlot);


        verticalLayout_4->addLayout(horizontalLayout_10);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setObjectName(QStringLiteral("horizontalLayout_15"));
        label_15 = new QLabel(tab);
        label_15->setObjectName(QStringLiteral("label_15"));
        label_15->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_15->addWidget(label_15);

        kcfg_coloredPlot = new QCheckBox(tab);
        kcfg_coloredPlot->setObjectName(QStringLiteral("kcfg_coloredPlot"));

        horizontalLayout_15->addWidget(kcfg_coloredPlot);


        verticalLayout_4->addLayout(horizontalLayout_15);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName(QStringLiteral("horizontalLayout_11"));
        label_11 = new QLabel(tab);
        label_11->setObjectName(QStringLiteral("label_11"));
        label_11->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_11->addWidget(label_11);

        kcfg_plotGrid = new QCheckBox(tab);
        kcfg_plotGrid->setObjectName(QStringLiteral("kcfg_plotGrid"));

        horizontalLayout_11->addWidget(kcfg_plotGrid);


        verticalLayout_4->addLayout(horizontalLayout_11);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName(QStringLiteral("horizontalLayout_12"));
        label_12 = new QLabel(tab);
        label_12->setObjectName(QStringLiteral("label_12"));
        label_12->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_12->addWidget(label_12);

        kcfg_plotBorder = new QCheckBox(tab);
        kcfg_plotBorder->setObjectName(QStringLiteral("kcfg_plotBorder"));

        horizontalLayout_12->addWidget(kcfg_plotBorder);


        verticalLayout_4->addLayout(horizontalLayout_12);

        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName(QStringLiteral("horizontalLayout_17"));
        label_17 = new QLabel(tab);
        label_17->setObjectName(QStringLiteral("label_17"));
        label_17->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_17->addWidget(label_17);

        kcfg_plotLineWidth = new QSpinBox(tab);
        kcfg_plotLineWidth->setObjectName(QStringLiteral("kcfg_plotLineWidth"));
        kcfg_plotLineWidth->setMinimum(1);

        horizontalLayout_17->addWidget(kcfg_plotLineWidth);


        verticalLayout_4->addLayout(horizontalLayout_17);

        horizontalLayout_18 = new QHBoxLayout();
        horizontalLayout_18->setObjectName(QStringLiteral("horizontalLayout_18"));
        label_18 = new QLabel(tab);
        label_18->setObjectName(QStringLiteral("label_18"));
        label_18->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_18->addWidget(label_18);

        kcfg_plotSteps = new QSpinBox(tab);
        kcfg_plotSteps->setObjectName(QStringLiteral("kcfg_plotSteps"));
        kcfg_plotSteps->setMinimum(1);

        horizontalLayout_18->addWidget(kcfg_plotSteps);


        verticalLayout_4->addLayout(horizontalLayout_18);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName(QStringLiteral("horizontalLayout_13"));
        label_13 = new QLabel(tab);
        label_13->setObjectName(QStringLiteral("label_13"));
        label_13->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_13->addWidget(label_13);

        kcfg_plotSmoothing = new KComboBox(tab);
        kcfg_plotSmoothing->setObjectName(QStringLiteral("kcfg_plotSmoothing"));

        horizontalLayout_13->addWidget(kcfg_plotSmoothing);


        verticalLayout_4->addLayout(horizontalLayout_13);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName(QStringLiteral("horizontalLayout_14"));
        label_14 = new QLabel(tab);
        label_14->setObjectName(QStringLiteral("label_14"));
        label_14->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_14->addWidget(label_14);

        kcfg_plotStyle = new KComboBox(tab);
        kcfg_plotStyle->setObjectName(QStringLiteral("kcfg_plotStyle"));

        horizontalLayout_14->addWidget(kcfg_plotStyle);


        verticalLayout_4->addLayout(horizontalLayout_14);

        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName(QStringLiteral("horizontalLayout_16"));
        label_16 = new QLabel(tab);
        label_16->setObjectName(QStringLiteral("label_16"));
        label_16->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_16->addWidget(label_16);

        kcfg_plotLegend = new KComboBox(tab);
        kcfg_plotLegend->setObjectName(QStringLiteral("kcfg_plotLegend"));

        horizontalLayout_16->addWidget(kcfg_plotLegend);


        verticalLayout_4->addLayout(horizontalLayout_16);

        verticalSpacer_3 = new QSpacerItem(20, 22, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_3);

        qtabwidget->addTab(tab, QString());

        verticalLayout->addWidget(qtabwidget);

        QWidget::setTabOrder(kcfg_base, kcfg_fractionFormat);
        QWidget::setTabOrder(kcfg_fractionFormat, kcfg_minExp);
        QWidget::setTabOrder(kcfg_minExp, kcfg_indicateInfiniteSeries);
        QWidget::setTabOrder(kcfg_indicateInfiniteSeries, kcfg_useAllPrefixes);
        QWidget::setTabOrder(kcfg_useAllPrefixes, kcfg_negativeExponents);
        QWidget::setTabOrder(kcfg_negativeExponents, kcfg_postConversion);
        QWidget::setTabOrder(kcfg_postConversion, kcfg_angleUnit);
        QWidget::setTabOrder(kcfg_angleUnit, kcfg_structuring);
        QWidget::setTabOrder(kcfg_structuring, kcfg_inlinePlot);
        QWidget::setTabOrder(kcfg_inlinePlot, kcfg_coloredPlot);
        QWidget::setTabOrder(kcfg_coloredPlot, kcfg_plotGrid);
        QWidget::setTabOrder(kcfg_plotGrid, kcfg_plotBorder);
        QWidget::setTabOrder(kcfg_plotBorder, kcfg_plotLineWidth);
        QWidget::setTabOrder(kcfg_plotLineWidth, kcfg_plotSteps);
        QWidget::setTabOrder(kcfg_plotSteps, kcfg_plotSmoothing);
        QWidget::setTabOrder(kcfg_plotSmoothing, kcfg_plotStyle);
        QWidget::setTabOrder(kcfg_plotStyle, kcfg_plotLegend);

        retranslateUi(QalculateSettingsBase);

        qtabwidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(QalculateSettingsBase);
    } // setupUi

    void retranslateUi(QWidget *QalculateSettingsBase)
    {
        label->setText(tr2i18n("Number base:", Q_NULLPTR));
        label_5->setText(tr2i18n("Fraction format:", Q_NULLPTR));
        kcfg_fractionFormat->clear();
        kcfg_fractionFormat->insertItems(0, QStringList()
         << tr2i18n("Decimal", Q_NULLPTR)
         << tr2i18n("Exact", Q_NULLPTR)
         << tr2i18n("Fractional", Q_NULLPTR)
         << tr2i18n("Combined", Q_NULLPTR)
        );
        label_9->setText(tr2i18n("Numerical display:", Q_NULLPTR));
        kcfg_minExp->clear();
        kcfg_minExp->insertItems(0, QStringList()
         << tr2i18n("None", Q_NULLPTR)
         << tr2i18n("Pure", Q_NULLPTR)
         << tr2i18n("Scientific", Q_NULLPTR)
         << tr2i18n("Precision", Q_NULLPTR)
        );
        label_6->setText(tr2i18n("Indicate infinite series:", Q_NULLPTR));
        kcfg_indicateInfiniteSeries->setText(tr2i18n("Enabled", Q_NULLPTR));
        label_7->setText(tr2i18n("Use all SI prefixes:", Q_NULLPTR));
        kcfg_useAllPrefixes->setText(tr2i18n("Enabled", Q_NULLPTR));
        label_8->setText(tr2i18n("Use negative exponents:", Q_NULLPTR));
        kcfg_negativeExponents->setText(tr2i18n("Enabled", Q_NULLPTR));
        kcfg_scriptGroup->setTitle(tr2i18n("Scripts to autorun", Q_NULLPTR));
        qtabwidget->setTabText(qtabwidget->indexOf(tab_3), tr2i18n("General", Q_NULLPTR));
        label_2->setText(tr2i18n("Convert to best SI units:", Q_NULLPTR));
        kcfg_postConversion->setText(tr2i18n("Enabled", Q_NULLPTR));
        label_3->setText(tr2i18n("Angle unit:", Q_NULLPTR));
        kcfg_angleUnit->clear();
        kcfg_angleUnit->insertItems(0, QStringList()
         << tr2i18n("None", Q_NULLPTR)
         << tr2i18n("Radians", Q_NULLPTR)
         << tr2i18n("Degrees", Q_NULLPTR)
         << tr2i18n("Gradians", Q_NULLPTR)
        );
        label_4->setText(tr2i18n("Structuring Mode:", Q_NULLPTR));
        kcfg_structuring->clear();
        kcfg_structuring->insertItems(0, QStringList()
         << tr2i18n("None", Q_NULLPTR)
         << tr2i18n("Simplify", Q_NULLPTR)
         << tr2i18n("Factorize", Q_NULLPTR)
        );
        qtabwidget->setTabText(qtabwidget->indexOf(tab_2), tr2i18n("Evaluate", Q_NULLPTR));
        label_10->setText(tr2i18n("Display plots inline:", Q_NULLPTR));
        kcfg_inlinePlot->setText(tr2i18n("Enabled", Q_NULLPTR));
        label_15->setText(tr2i18n("Colored Plots:", Q_NULLPTR));
        kcfg_coloredPlot->setText(tr2i18n("Enabled", Q_NULLPTR));
        label_11->setText(tr2i18n("Show grid:", Q_NULLPTR));
        kcfg_plotGrid->setText(tr2i18n("Enabled", Q_NULLPTR));
        label_12->setText(tr2i18n("Show full borders:", Q_NULLPTR));
        kcfg_plotBorder->setText(tr2i18n("Enabled", Q_NULLPTR));
        label_17->setText(tr2i18n("Width of lines:", Q_NULLPTR));
        label_18->setText(tr2i18n("Sampling rate:", Q_NULLPTR));
        label_13->setText(tr2i18n("Smoothing Mode:", Q_NULLPTR));
        kcfg_plotSmoothing->clear();
        kcfg_plotSmoothing->insertItems(0, QStringList()
         << tr2i18n("None", Q_NULLPTR)
         << tr2i18n("Monotonic", Q_NULLPTR)
         << tr2i18n("Natural cubic Splines", Q_NULLPTR)
         << tr2i18n("Bezier", Q_NULLPTR)
         << tr2i18n("Bezier (monotonic)", Q_NULLPTR)
        );
        label_14->setText(tr2i18n("Plot Style:", Q_NULLPTR));
        kcfg_plotStyle->clear();
        kcfg_plotStyle->insertItems(0, QStringList()
         << tr2i18n("Lines", Q_NULLPTR)
         << tr2i18n("Points", Q_NULLPTR)
         << tr2i18n("Points and Lines", Q_NULLPTR)
         << tr2i18n("Boxes", Q_NULLPTR)
         << tr2i18n("Histogram", Q_NULLPTR)
         << tr2i18n("Steps", "Plot Style")
         << tr2i18n("Candlesticks", Q_NULLPTR)
         << tr2i18n("Dots", Q_NULLPTR)
        );
        label_16->setText(tr2i18n("Legend Position:", Q_NULLPTR));
        kcfg_plotLegend->clear();
        kcfg_plotLegend->insertItems(0, QStringList()
         << tr2i18n("Hide legend", Q_NULLPTR)
         << tr2i18n("Top-left", Q_NULLPTR)
         << tr2i18n("Top-right", Q_NULLPTR)
         << tr2i18n("Bottom-left", Q_NULLPTR)
         << tr2i18n("Bottom-right", Q_NULLPTR)
         << tr2i18n("Below", Q_NULLPTR)
         << tr2i18n("Outside", Q_NULLPTR)
        );
        qtabwidget->setTabText(qtabwidget->indexOf(tab), tr2i18n("Plotting", Q_NULLPTR));
        Q_UNUSED(QalculateSettingsBase);
    } // retranslateUi

};

namespace Ui {
    class QalculateSettingsBase: public Ui_QalculateSettingsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

