/****************************************************************************
** Meta object code from reading C++ file 'cantor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/cantor-17.08.3/src/cantor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cantor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CantorShell_t {
    QByteArrayData data[16];
    char stringdata0[181];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CantorShell_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CantorShell_t qt_meta_stringdata_CantorShell = {
    {
QT_MOC_LITERAL(0, 0, 11), // "CantorShell"
QT_MOC_LITERAL(1, 12, 12), // "addWorksheet"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 11), // "backendName"
QT_MOC_LITERAL(4, 38, 7), // "fileNew"
QT_MOC_LITERAL(5, 46, 8), // "fileOpen"
QT_MOC_LITERAL(6, 55, 20), // "optionsConfigureKeys"
QT_MOC_LITERAL(7, 76, 17), // "activateWorksheet"
QT_MOC_LITERAL(8, 94, 5), // "index"
QT_MOC_LITERAL(9, 100, 13), // "setTabCaption"
QT_MOC_LITERAL(10, 114, 3), // "tab"
QT_MOC_LITERAL(11, 118, 8), // "closeTab"
QT_MOC_LITERAL(12, 127, 12), // "showSettings"
QT_MOC_LITERAL(13, 140, 16), // "downloadExamples"
QT_MOC_LITERAL(14, 157, 11), // "openExample"
QT_MOC_LITERAL(15, 169, 11) // "updatePanel"

    },
    "CantorShell\0addWorksheet\0\0backendName\0"
    "fileNew\0fileOpen\0optionsConfigureKeys\0"
    "activateWorksheet\0index\0setTabCaption\0"
    "tab\0closeTab\0showSettings\0downloadExamples\0"
    "openExample\0updatePanel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CantorShell[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x0a /* Public */,
       1,    1,   80,    2, 0x0a /* Public */,
       4,    0,   83,    2, 0x08 /* Private */,
       5,    0,   84,    2, 0x08 /* Private */,
       6,    0,   85,    2, 0x08 /* Private */,
       7,    1,   86,    2, 0x08 /* Private */,
       9,    1,   89,    2, 0x08 /* Private */,
      11,    1,   92,    2, 0x08 /* Private */,
      11,    0,   95,    2, 0x28 /* Private | MethodCloned */,
      12,    0,   96,    2, 0x08 /* Private */,
      13,    0,   97,    2, 0x08 /* Private */,
      14,    0,   98,    2, 0x08 /* Private */,
      15,    0,   99,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void CantorShell::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CantorShell *_t = static_cast<CantorShell *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->addWorksheet(); break;
        case 1: _t->addWorksheet((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->fileNew(); break;
        case 3: _t->fileOpen(); break;
        case 4: _t->optionsConfigureKeys(); break;
        case 5: _t->activateWorksheet((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->setTabCaption((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->closeTab((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->closeTab(); break;
        case 9: _t->showSettings(); break;
        case 10: _t->downloadExamples(); break;
        case 11: _t->openExample(); break;
        case 12: _t->updatePanel(); break;
        default: ;
        }
    }
}

const QMetaObject CantorShell::staticMetaObject = {
    { &KParts::MainWindow::staticMetaObject, qt_meta_stringdata_CantorShell.data,
      qt_meta_data_CantorShell,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *CantorShell::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CantorShell::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CantorShell.stringdata0))
        return static_cast<void*>(this);
    return KParts::MainWindow::qt_metacast(_clname);
}

int CantorShell::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::MainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
