#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'qalculateplotdialog.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QALCULATEPLOTDIALOG_H
#define UI_QALCULATEPLOTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_QalculatePlotAssistantBase
{
public:
    QGridLayout *gridLayout;
    QTabWidget *qtabwidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout;
    QTableWidget *functionTable;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer;
    QPushButton *addButton;
    QPushButton *removeButton;
    QPushButton *clearButton;
    QHBoxLayout *horizontalLayout;
    QLabel *label_3;
    KLineEdit *xVarEdit;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_4;
    KComboBox *styleBox;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_5;
    KComboBox *smoothingBox;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *label;
    QHBoxLayout *horizontalLayout_4;
    KLineEdit *xMinEdit;
    QLabel *label_2;
    KLineEdit *xMaxEdit;
    QRadioButton *stepsButton;
    QRadioButton *stepButton;
    KLineEdit *stepEdit;
    KLineEdit *stepsEdit;
    QWidget *tab_4;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_25;
    QLabel *label_19;
    KLineEdit *plotTitleEdit;
    QHBoxLayout *horizontalLayout_24;
    QLabel *label_20;
    KLineEdit *xLabelEdit;
    QHBoxLayout *horizontalLayout_23;
    QLabel *label_21;
    KLineEdit *yLabelEdit;
    QHBoxLayout *horizontalLayout_22;
    QLabel *label_22;
    KComboBox *legendBox;
    QHBoxLayout *horizontalLayout_21;
    QCheckBox *gridCheckBox;
    QCheckBox *borderCheckBox;
    QHBoxLayout *horizontalLayout_20;
    QCheckBox *colorCheckBox;
    QCheckBox *inlineCheckBox;
    QHBoxLayout *horizontalLayout_19;
    QCheckBox *xLogCheckBox;
    KLineEdit *xLogEdit;
    QHBoxLayout *horizontalLayout_7;
    QCheckBox *yLogCheckBox;
    KLineEdit *yLogEdit;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_3;
    QCheckBox *saveCheckBox;
    KLineEdit *saveFileEdit;
    QLabel *label_23;
    KComboBox *saveFileBox;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;
    QButtonGroup *buttonGroup;

    void setupUi(QWidget *QalculatePlotAssistantBase)
    {
        if (QalculatePlotAssistantBase->objectName().isEmpty())
            QalculatePlotAssistantBase->setObjectName(QStringLiteral("QalculatePlotAssistantBase"));
        QalculatePlotAssistantBase->resize(470, 489);
        gridLayout = new QGridLayout(QalculatePlotAssistantBase);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        qtabwidget = new QTabWidget(QalculatePlotAssistantBase);
        qtabwidget->setObjectName(QStringLiteral("qtabwidget"));
        tab = new QWidget();
        tab->setObjectName(QStringLiteral("tab"));
        verticalLayout = new QVBoxLayout(tab);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        functionTable = new QTableWidget(tab);
        if (functionTable->columnCount() < 2)
            functionTable->setColumnCount(2);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        functionTable->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        functionTable->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        functionTable->setObjectName(QStringLiteral("functionTable"));
        functionTable->setSelectionMode(QAbstractItemView::SingleSelection);
        functionTable->setSelectionBehavior(QAbstractItemView::SelectRows);
        functionTable->verticalHeader()->setVisible(false);

        verticalLayout->addWidget(functionTable);

        groupBox_2 = new QGroupBox(tab);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        horizontalLayout_5 = new QHBoxLayout(groupBox_2);
        horizontalLayout_5->setObjectName(QStringLiteral("horizontalLayout_5"));
        horizontalSpacer = new QSpacerItem(220, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer);

        addButton = new QPushButton(groupBox_2);
        buttonGroup = new QButtonGroup(QalculatePlotAssistantBase);
        buttonGroup->setObjectName(QStringLiteral("buttonGroup"));
        buttonGroup->addButton(addButton);
        addButton->setObjectName(QStringLiteral("addButton"));

        horizontalLayout_5->addWidget(addButton);

        removeButton = new QPushButton(groupBox_2);
        buttonGroup->addButton(removeButton);
        removeButton->setObjectName(QStringLiteral("removeButton"));

        horizontalLayout_5->addWidget(removeButton);

        clearButton = new QPushButton(groupBox_2);
        buttonGroup->addButton(clearButton);
        clearButton->setObjectName(QStringLiteral("clearButton"));

        horizontalLayout_5->addWidget(clearButton);


        verticalLayout->addWidget(groupBox_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label_3 = new QLabel(tab);
        label_3->setObjectName(QStringLiteral("label_3"));
        label_3->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout->addWidget(label_3);

        xVarEdit = new KLineEdit(tab);
        xVarEdit->setObjectName(QStringLiteral("xVarEdit"));
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(xVarEdit->sizePolicy().hasHeightForWidth());
        xVarEdit->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(xVarEdit);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        label_4 = new QLabel(tab);
        label_4->setObjectName(QStringLiteral("label_4"));
        label_4->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_2->addWidget(label_4);

        styleBox = new KComboBox(tab);
        styleBox->setObjectName(QStringLiteral("styleBox"));

        horizontalLayout_2->addWidget(styleBox);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        label_5 = new QLabel(tab);
        label_5->setObjectName(QStringLiteral("label_5"));
        label_5->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_3->addWidget(label_5);

        smoothingBox = new KComboBox(tab);
        smoothingBox->setObjectName(QStringLiteral("smoothingBox"));

        horizontalLayout_3->addWidget(smoothingBox);


        verticalLayout->addLayout(horizontalLayout_3);

        groupBox = new QGroupBox(tab);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        label = new QLabel(groupBox);
        label->setObjectName(QStringLiteral("label"));

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        xMinEdit = new KLineEdit(groupBox);
        xMinEdit->setObjectName(QStringLiteral("xMinEdit"));
        sizePolicy.setHeightForWidth(xMinEdit->sizePolicy().hasHeightForWidth());
        xMinEdit->setSizePolicy(sizePolicy);

        horizontalLayout_4->addWidget(xMinEdit);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QStringLiteral("label_2"));

        horizontalLayout_4->addWidget(label_2);

        xMaxEdit = new KLineEdit(groupBox);
        xMaxEdit->setObjectName(QStringLiteral("xMaxEdit"));
        sizePolicy.setHeightForWidth(xMaxEdit->sizePolicy().hasHeightForWidth());
        xMaxEdit->setSizePolicy(sizePolicy);

        horizontalLayout_4->addWidget(xMaxEdit);


        gridLayout_2->addLayout(horizontalLayout_4, 0, 1, 1, 1);

        stepsButton = new QRadioButton(groupBox);
        stepsButton->setObjectName(QStringLiteral("stepsButton"));
        stepsButton->setChecked(true);

        gridLayout_2->addWidget(stepsButton, 1, 0, 1, 1);

        stepButton = new QRadioButton(groupBox);
        stepButton->setObjectName(QStringLiteral("stepButton"));

        gridLayout_2->addWidget(stepButton, 2, 0, 1, 1);

        stepEdit = new KLineEdit(groupBox);
        stepEdit->setObjectName(QStringLiteral("stepEdit"));
        sizePolicy.setHeightForWidth(stepEdit->sizePolicy().hasHeightForWidth());
        stepEdit->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(stepEdit, 2, 1, 1, 1);

        stepsEdit = new KLineEdit(groupBox);
        stepsEdit->setObjectName(QStringLiteral("stepsEdit"));
        sizePolicy.setHeightForWidth(stepsEdit->sizePolicy().hasHeightForWidth());
        stepsEdit->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(stepsEdit, 1, 1, 1, 1);


        verticalLayout->addWidget(groupBox);

        qtabwidget->addTab(tab, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName(QStringLiteral("tab_4"));
        verticalLayout_3 = new QVBoxLayout(tab_4);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        horizontalLayout_25 = new QHBoxLayout();
        horizontalLayout_25->setObjectName(QStringLiteral("horizontalLayout_25"));
        label_19 = new QLabel(tab_4);
        label_19->setObjectName(QStringLiteral("label_19"));

        horizontalLayout_25->addWidget(label_19);

        plotTitleEdit = new KLineEdit(tab_4);
        plotTitleEdit->setObjectName(QStringLiteral("plotTitleEdit"));
        sizePolicy.setHeightForWidth(plotTitleEdit->sizePolicy().hasHeightForWidth());
        plotTitleEdit->setSizePolicy(sizePolicy);

        horizontalLayout_25->addWidget(plotTitleEdit);


        verticalLayout_3->addLayout(horizontalLayout_25);

        horizontalLayout_24 = new QHBoxLayout();
        horizontalLayout_24->setObjectName(QStringLiteral("horizontalLayout_24"));
        label_20 = new QLabel(tab_4);
        label_20->setObjectName(QStringLiteral("label_20"));

        horizontalLayout_24->addWidget(label_20);

        xLabelEdit = new KLineEdit(tab_4);
        xLabelEdit->setObjectName(QStringLiteral("xLabelEdit"));
        sizePolicy.setHeightForWidth(xLabelEdit->sizePolicy().hasHeightForWidth());
        xLabelEdit->setSizePolicy(sizePolicy);

        horizontalLayout_24->addWidget(xLabelEdit);


        verticalLayout_3->addLayout(horizontalLayout_24);

        horizontalLayout_23 = new QHBoxLayout();
        horizontalLayout_23->setObjectName(QStringLiteral("horizontalLayout_23"));
        label_21 = new QLabel(tab_4);
        label_21->setObjectName(QStringLiteral("label_21"));

        horizontalLayout_23->addWidget(label_21);

        yLabelEdit = new KLineEdit(tab_4);
        yLabelEdit->setObjectName(QStringLiteral("yLabelEdit"));
        sizePolicy.setHeightForWidth(yLabelEdit->sizePolicy().hasHeightForWidth());
        yLabelEdit->setSizePolicy(sizePolicy);

        horizontalLayout_23->addWidget(yLabelEdit);


        verticalLayout_3->addLayout(horizontalLayout_23);

        horizontalLayout_22 = new QHBoxLayout();
        horizontalLayout_22->setObjectName(QStringLiteral("horizontalLayout_22"));
        label_22 = new QLabel(tab_4);
        label_22->setObjectName(QStringLiteral("label_22"));

        horizontalLayout_22->addWidget(label_22);

        legendBox = new KComboBox(tab_4);
        legendBox->setObjectName(QStringLiteral("legendBox"));

        horizontalLayout_22->addWidget(legendBox);


        verticalLayout_3->addLayout(horizontalLayout_22);

        horizontalLayout_21 = new QHBoxLayout();
        horizontalLayout_21->setObjectName(QStringLiteral("horizontalLayout_21"));
        gridCheckBox = new QCheckBox(tab_4);
        gridCheckBox->setObjectName(QStringLiteral("gridCheckBox"));

        horizontalLayout_21->addWidget(gridCheckBox);

        borderCheckBox = new QCheckBox(tab_4);
        borderCheckBox->setObjectName(QStringLiteral("borderCheckBox"));

        horizontalLayout_21->addWidget(borderCheckBox);


        verticalLayout_3->addLayout(horizontalLayout_21);

        horizontalLayout_20 = new QHBoxLayout();
        horizontalLayout_20->setObjectName(QStringLiteral("horizontalLayout_20"));
        colorCheckBox = new QCheckBox(tab_4);
        colorCheckBox->setObjectName(QStringLiteral("colorCheckBox"));

        horizontalLayout_20->addWidget(colorCheckBox);

        inlineCheckBox = new QCheckBox(tab_4);
        inlineCheckBox->setObjectName(QStringLiteral("inlineCheckBox"));

        horizontalLayout_20->addWidget(inlineCheckBox);


        verticalLayout_3->addLayout(horizontalLayout_20);

        horizontalLayout_19 = new QHBoxLayout();
        horizontalLayout_19->setObjectName(QStringLiteral("horizontalLayout_19"));
        xLogCheckBox = new QCheckBox(tab_4);
        xLogCheckBox->setObjectName(QStringLiteral("xLogCheckBox"));

        horizontalLayout_19->addWidget(xLogCheckBox);

        xLogEdit = new KLineEdit(tab_4);
        xLogEdit->setObjectName(QStringLiteral("xLogEdit"));
        sizePolicy.setHeightForWidth(xLogEdit->sizePolicy().hasHeightForWidth());
        xLogEdit->setSizePolicy(sizePolicy);

        horizontalLayout_19->addWidget(xLogEdit);


        verticalLayout_3->addLayout(horizontalLayout_19);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName(QStringLiteral("horizontalLayout_7"));
        yLogCheckBox = new QCheckBox(tab_4);
        yLogCheckBox->setObjectName(QStringLiteral("yLogCheckBox"));

        horizontalLayout_7->addWidget(yLogCheckBox);

        yLogEdit = new KLineEdit(tab_4);
        yLogEdit->setObjectName(QStringLiteral("yLogEdit"));
        sizePolicy.setHeightForWidth(yLogEdit->sizePolicy().hasHeightForWidth());
        yLogEdit->setSizePolicy(sizePolicy);

        horizontalLayout_7->addWidget(yLogEdit);


        verticalLayout_3->addLayout(horizontalLayout_7);

        groupBox_3 = new QGroupBox(tab_4);
        groupBox_3->setObjectName(QStringLiteral("groupBox_3"));
        gridLayout_3 = new QGridLayout(groupBox_3);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        saveCheckBox = new QCheckBox(groupBox_3);
        saveCheckBox->setObjectName(QStringLiteral("saveCheckBox"));

        gridLayout_3->addWidget(saveCheckBox, 0, 0, 1, 1);

        saveFileEdit = new KLineEdit(groupBox_3);
        saveFileEdit->setObjectName(QStringLiteral("saveFileEdit"));
        sizePolicy.setHeightForWidth(saveFileEdit->sizePolicy().hasHeightForWidth());
        saveFileEdit->setSizePolicy(sizePolicy);
        saveFileEdit->setProperty("showClearButton", QVariant(false));

        gridLayout_3->addWidget(saveFileEdit, 0, 1, 1, 1);

        label_23 = new QLabel(groupBox_3);
        label_23->setObjectName(QStringLiteral("label_23"));

        gridLayout_3->addWidget(label_23, 1, 0, 1, 1);

        saveFileBox = new KComboBox(groupBox_3);
        saveFileBox->setObjectName(QStringLiteral("saveFileBox"));

        gridLayout_3->addWidget(saveFileBox, 1, 1, 1, 1);


        verticalLayout_3->addWidget(groupBox_3);

        verticalSpacer = new QSpacerItem(20, 119, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        qtabwidget->addTab(tab_4, QString());

        gridLayout->addWidget(qtabwidget, 0, 0, 1, 1);

        buttonBox = new QDialogButtonBox(QalculatePlotAssistantBase);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);
        buttonBox->setCenterButtons(false);

        gridLayout->addWidget(buttonBox, 1, 0, 1, 1);

        QWidget::setTabOrder(functionTable, xVarEdit);
        QWidget::setTabOrder(xVarEdit, styleBox);
        QWidget::setTabOrder(styleBox, smoothingBox);
        QWidget::setTabOrder(smoothingBox, xMinEdit);
        QWidget::setTabOrder(xMinEdit, xMaxEdit);
        QWidget::setTabOrder(xMaxEdit, stepsButton);
        QWidget::setTabOrder(stepsButton, stepsEdit);
        QWidget::setTabOrder(stepsEdit, stepButton);
        QWidget::setTabOrder(stepButton, stepEdit);
        QWidget::setTabOrder(stepEdit, plotTitleEdit);
        QWidget::setTabOrder(plotTitleEdit, xLabelEdit);
        QWidget::setTabOrder(xLabelEdit, yLabelEdit);
        QWidget::setTabOrder(yLabelEdit, legendBox);
        QWidget::setTabOrder(legendBox, gridCheckBox);
        QWidget::setTabOrder(gridCheckBox, borderCheckBox);
        QWidget::setTabOrder(borderCheckBox, colorCheckBox);
        QWidget::setTabOrder(colorCheckBox, inlineCheckBox);
        QWidget::setTabOrder(inlineCheckBox, xLogCheckBox);
        QWidget::setTabOrder(xLogCheckBox, xLogEdit);
        QWidget::setTabOrder(xLogEdit, yLogCheckBox);
        QWidget::setTabOrder(yLogCheckBox, yLogEdit);
        QWidget::setTabOrder(yLogEdit, saveCheckBox);
        QWidget::setTabOrder(saveCheckBox, saveFileEdit);
        QWidget::setTabOrder(saveFileEdit, saveFileBox);

        retranslateUi(QalculatePlotAssistantBase);
        QObject::connect(stepButton, SIGNAL(toggled(bool)), stepEdit, SLOT(setEnabled(bool)));
        QObject::connect(xLogCheckBox, SIGNAL(toggled(bool)), xLogEdit, SLOT(setEnabled(bool)));
        QObject::connect(yLogCheckBox, SIGNAL(toggled(bool)), yLogEdit, SLOT(setEnabled(bool)));
        QObject::connect(saveCheckBox, SIGNAL(toggled(bool)), saveFileEdit, SLOT(setEnabled(bool)));
        QObject::connect(saveCheckBox, SIGNAL(toggled(bool)), saveFileBox, SLOT(setEnabled(bool)));
        QObject::connect(saveCheckBox, SIGNAL(toggled(bool)), label_23, SLOT(setEnabled(bool)));
        QObject::connect(stepsButton, SIGNAL(toggled(bool)), stepsEdit, SLOT(setEnabled(bool)));

        qtabwidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(QalculatePlotAssistantBase);
    } // setupUi

    void retranslateUi(QWidget *QalculatePlotAssistantBase)
    {
        QalculatePlotAssistantBase->setWindowTitle(tr2i18n("Cantor - Plot Dialog", Q_NULLPTR));
        QTableWidgetItem *___qtablewidgetitem = functionTable->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Title", Q_NULLPTR));
        QTableWidgetItem *___qtablewidgetitem1 = functionTable->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Expression", Q_NULLPTR));
        groupBox_2->setTitle(QString());
        addButton->setText(tr2i18n("Add", Q_NULLPTR));
        removeButton->setText(tr2i18n("Remove", Q_NULLPTR));
        clearButton->setText(tr2i18n("Clear List", Q_NULLPTR));
        label_3->setText(tr2i18n("X variable", Q_NULLPTR));
        xVarEdit->setText(tr2i18n("x", Q_NULLPTR));
        label_4->setText(tr2i18n("Style", Q_NULLPTR));
        styleBox->clear();
        styleBox->insertItems(0, QStringList()
         << tr2i18n("Lines", Q_NULLPTR)
         << tr2i18n("Points", Q_NULLPTR)
         << tr2i18n("Points and Lines", Q_NULLPTR)
         << tr2i18n("Boxes", Q_NULLPTR)
         << tr2i18n("Histogram", Q_NULLPTR)
         << tr2i18n("Steps", Q_NULLPTR)
         << tr2i18n("Candlesticks", Q_NULLPTR)
         << tr2i18n("Dots", Q_NULLPTR)
        );
        label_5->setText(tr2i18n("Smoothing", Q_NULLPTR));
        smoothingBox->clear();
        smoothingBox->insertItems(0, QStringList()
         << tr2i18n("None", Q_NULLPTR)
         << tr2i18n("Monotonic", Q_NULLPTR)
         << tr2i18n("Natural Cubic Splines", Q_NULLPTR)
         << tr2i18n("Bezier", Q_NULLPTR)
         << tr2i18n("Bezier (monotonic)", Q_NULLPTR)
        );
        groupBox->setTitle(tr2i18n("Function Range", Q_NULLPTR));
        label->setText(tr2i18n("X range", Q_NULLPTR));
        xMinEdit->setText(tr2i18n("0", Q_NULLPTR));
        label_2->setText(tr2i18n("-", Q_NULLPTR));
        xMaxEdit->setText(tr2i18n("10", Q_NULLPTR));
        stepsButton->setText(tr2i18n("Sa&mpling rate", Q_NULLPTR));
        stepButton->setText(tr2i18n("Step si&ze", Q_NULLPTR));
        qtabwidget->setTabText(qtabwidget->indexOf(tab), tr2i18n("Functions", Q_NULLPTR));
        label_19->setText(tr2i18n("Plot title", Q_NULLPTR));
        label_20->setText(tr2i18n("X-axis label", Q_NULLPTR));
        label_21->setText(tr2i18n("Y-axis label", Q_NULLPTR));
        label_22->setText(tr2i18n("Legend position", Q_NULLPTR));
        legendBox->clear();
        legendBox->insertItems(0, QStringList()
         << tr2i18n("Hide legend", Q_NULLPTR)
         << tr2i18n("Top-left", Q_NULLPTR)
         << tr2i18n("Top-right", Q_NULLPTR)
         << tr2i18n("Bottom-left", Q_NULLPTR)
         << tr2i18n("Bottom-right", Q_NULLPTR)
         << tr2i18n("Below", Q_NULLPTR)
         << tr2i18n("Outside", Q_NULLPTR)
        );
        gridCheckBox->setText(tr2i18n("Display Grid", Q_NULLPTR));
        borderCheckBox->setText(tr2i18n("Display full border", Q_NULLPTR));
        colorCheckBox->setText(tr2i18n("Use Colors", Q_NULLPTR));
        inlineCheckBox->setText(tr2i18n("Display inline", Q_NULLPTR));
        xLogCheckBox->setText(tr2i18n("Logarithmic x scale", Q_NULLPTR));
        yLogCheckBox->setText(tr2i18n("Logarithmic y scale", Q_NULLPTR));
        groupBox_3->setTitle(tr2i18n("File Options", Q_NULLPTR));
        saveCheckBox->setText(tr2i18n("Save plot to file", Q_NULLPTR));
        label_23->setText(tr2i18n("File type", Q_NULLPTR));
        saveFileBox->clear();
        saveFileBox->insertItems(0, QStringList()
         << tr2i18n("Detect from filename", Q_NULLPTR)
         << tr2i18n("PNG", Q_NULLPTR)
         << tr2i18n("PS", Q_NULLPTR)
         << tr2i18n("EPS", Q_NULLPTR)
         << tr2i18n("LaTeX", Q_NULLPTR)
         << tr2i18n("SVG", Q_NULLPTR)
         << tr2i18n("FIG", Q_NULLPTR)
        );
        qtabwidget->setTabText(qtabwidget->indexOf(tab_4), tr2i18n("Options", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class QalculatePlotAssistantBase: public Ui_QalculatePlotAssistantBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QALCULATEPLOTDIALOG_H

