/****************************************************************************
** Meta object code from reading C++ file 'rserver.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/cantor-17.08.3/src/backends/R/rserver/rserver.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'rserver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_RServer_t {
    QByteArrayData data[28];
    char stringdata0[301];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RServer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RServer_t qt_meta_stringdata_RServer = {
    {
QT_MOC_LITERAL(0, 0, 7), // "RServer"
QT_MOC_LITERAL(1, 8, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 24, 16), // "org.kde.Cantor.R"
QT_MOC_LITERAL(3, 41, 5), // "ready"
QT_MOC_LITERAL(4, 47, 0), // ""
QT_MOC_LITERAL(5, 48, 13), // "statusChanged"
QT_MOC_LITERAL(6, 62, 6), // "status"
QT_MOC_LITERAL(7, 69, 18), // "expressionFinished"
QT_MOC_LITERAL(8, 88, 10), // "returnCode"
QT_MOC_LITERAL(9, 99, 4), // "text"
QT_MOC_LITERAL(10, 104, 18), // "completionFinished"
QT_MOC_LITERAL(11, 123, 5), // "token"
QT_MOC_LITERAL(12, 129, 7), // "options"
QT_MOC_LITERAL(13, 137, 15), // "showFilesNeeded"
QT_MOC_LITERAL(14, 153, 5), // "files"
QT_MOC_LITERAL(15, 159, 14), // "inputRequested"
QT_MOC_LITERAL(16, 174, 6), // "prompt"
QT_MOC_LITERAL(17, 181, 15), // "requestAnswered"
QT_MOC_LITERAL(18, 197, 10), // "symbolList"
QT_MOC_LITERAL(19, 208, 9), // "variables"
QT_MOC_LITERAL(20, 218, 9), // "functions"
QT_MOC_LITERAL(21, 228, 10), // "runCommand"
QT_MOC_LITERAL(22, 239, 3), // "cmd"
QT_MOC_LITERAL(23, 243, 8), // "internal"
QT_MOC_LITERAL(24, 252, 13), // "answerRequest"
QT_MOC_LITERAL(25, 266, 6), // "answer"
QT_MOC_LITERAL(26, 273, 15), // "completeCommand"
QT_MOC_LITERAL(27, 289, 11) // "listSymbols"

    },
    "RServer\0D-Bus Interface\0org.kde.Cantor.R\0"
    "ready\0\0statusChanged\0status\0"
    "expressionFinished\0returnCode\0text\0"
    "completionFinished\0token\0options\0"
    "showFilesNeeded\0files\0inputRequested\0"
    "prompt\0requestAnswered\0symbolList\0"
    "variables\0functions\0runCommand\0cmd\0"
    "internal\0answerRequest\0answer\0"
    "completeCommand\0listSymbols"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RServer[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
      13,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,   81,    4, 0x06 /* Public */,
       5,    1,   82,    4, 0x06 /* Public */,
       7,    2,   85,    4, 0x06 /* Public */,
      10,    2,   90,    4, 0x06 /* Public */,
      13,    1,   95,    4, 0x06 /* Public */,
      15,    1,   98,    4, 0x06 /* Public */,
      17,    0,  101,    4, 0x06 /* Public */,
      18,    2,  102,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      21,    2,  107,    4, 0x0a /* Public */,
      21,    1,  112,    4, 0x2a /* Public | MethodCloned */,
      24,    1,  115,    4, 0x0a /* Public */,
      26,    1,  118,    4, 0x0a /* Public */,
      27,    0,  121,    4, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    8,    9,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,   11,   12,
    QMetaType::Void, QMetaType::QStringList,   14,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QStringList, QMetaType::QStringList,   19,   20,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,   22,   23,
    QMetaType::Void, QMetaType::QString,   22,
    QMetaType::Void, QMetaType::QString,   25,
    QMetaType::Void, QMetaType::QString,   22,
    QMetaType::Void,

       0        // eod
};

void RServer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        RServer *_t = static_cast<RServer *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->ready(); break;
        case 1: _t->statusChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->expressionFinished((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->completionFinished((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 4: _t->showFilesNeeded((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 5: _t->inputRequested((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->requestAnswered(); break;
        case 7: _t->symbolList((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 8: _t->runCommand((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 9: _t->runCommand((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->answerRequest((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->completeCommand((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->listSymbols(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (RServer::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&RServer::ready)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (RServer::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&RServer::statusChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (RServer::*_t)(int , const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&RServer::expressionFinished)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (RServer::*_t)(const QString & , const QStringList & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&RServer::completionFinished)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (RServer::*_t)(const QStringList & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&RServer::showFilesNeeded)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (RServer::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&RServer::inputRequested)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (RServer::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&RServer::requestAnswered)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (RServer::*_t)(const QStringList & , const QStringList & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&RServer::symbolList)) {
                *result = 7;
                return;
            }
        }
    }
}

const QMetaObject RServer::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_RServer.data,
      qt_meta_data_RServer,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *RServer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RServer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RServer.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int RServer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void RServer::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void RServer::statusChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void RServer::expressionFinished(int _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void RServer::completionFinished(const QString & _t1, const QStringList & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void RServer::showFilesNeeded(const QStringList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void RServer::inputRequested(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void RServer::requestAnswered()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void RServer::symbolList(const QStringList & _t1, const QStringList & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
