/****************************************************************************
** Meta object code from reading C++ file 'worksheet.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/cantor-17.08.3/src/worksheet.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'worksheet.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Worksheet_t {
    QByteArrayData data[108];
    char stringdata0[1455];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Worksheet_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Worksheet_t qt_meta_stringdata_Worksheet = {
    {
QT_MOC_LITERAL(0, 0, 9), // "Worksheet"
QT_MOC_LITERAL(1, 10, 8), // "modified"
QT_MOC_LITERAL(2, 19, 0), // ""
QT_MOC_LITERAL(3, 20, 14), // "sessionChanged"
QT_MOC_LITERAL(4, 35, 8), // "showHelp"
QT_MOC_LITERAL(5, 44, 4), // "help"
QT_MOC_LITERAL(6, 49, 12), // "updatePrompt"
QT_MOC_LITERAL(7, 62, 13), // "undoAvailable"
QT_MOC_LITERAL(8, 76, 13), // "redoAvailable"
QT_MOC_LITERAL(9, 90, 4), // "undo"
QT_MOC_LITERAL(10, 95, 4), // "redo"
QT_MOC_LITERAL(11, 100, 12), // "cutAvailable"
QT_MOC_LITERAL(12, 113, 13), // "copyAvailable"
QT_MOC_LITERAL(13, 127, 14), // "pasteAvailable"
QT_MOC_LITERAL(14, 142, 3), // "cut"
QT_MOC_LITERAL(15, 146, 4), // "copy"
QT_MOC_LITERAL(16, 151, 5), // "paste"
QT_MOC_LITERAL(17, 157, 18), // "appendCommandEntry"
QT_MOC_LITERAL(18, 176, 15), // "WorksheetEntry*"
QT_MOC_LITERAL(19, 192, 4), // "text"
QT_MOC_LITERAL(20, 197, 15), // "appendTextEntry"
QT_MOC_LITERAL(21, 213, 16), // "appendImageEntry"
QT_MOC_LITERAL(22, 230, 20), // "appendPageBreakEntry"
QT_MOC_LITERAL(23, 251, 16), // "appendLatexEntry"
QT_MOC_LITERAL(24, 268, 18), // "insertCommandEntry"
QT_MOC_LITERAL(25, 287, 7), // "current"
QT_MOC_LITERAL(26, 295, 15), // "insertTextEntry"
QT_MOC_LITERAL(27, 311, 16), // "insertImageEntry"
QT_MOC_LITERAL(28, 328, 20), // "insertPageBreakEntry"
QT_MOC_LITERAL(29, 349, 16), // "insertLatexEntry"
QT_MOC_LITERAL(30, 366, 24), // "insertCommandEntryBefore"
QT_MOC_LITERAL(31, 391, 21), // "insertTextEntryBefore"
QT_MOC_LITERAL(32, 413, 22), // "insertImageEntryBefore"
QT_MOC_LITERAL(33, 436, 26), // "insertPageBreakEntryBefore"
QT_MOC_LITERAL(34, 463, 22), // "insertLatexEntryBefore"
QT_MOC_LITERAL(35, 486, 12), // "updateLayout"
QT_MOC_LITERAL(36, 499, 15), // "updateEntrySize"
QT_MOC_LITERAL(37, 515, 5), // "entry"
QT_MOC_LITERAL(38, 521, 5), // "print"
QT_MOC_LITERAL(39, 527, 9), // "QPrinter*"
QT_MOC_LITERAL(40, 537, 7), // "printer"
QT_MOC_LITERAL(41, 545, 10), // "focusEntry"
QT_MOC_LITERAL(42, 556, 8), // "evaluate"
QT_MOC_LITERAL(43, 565, 20), // "evaluateCurrentEntry"
QT_MOC_LITERAL(44, 586, 9), // "interrupt"
QT_MOC_LITERAL(45, 596, 31), // "interruptCurrentEntryEvaluation"
QT_MOC_LITERAL(46, 628, 17), // "completionEnabled"
QT_MOC_LITERAL(47, 646, 13), // "highlightItem"
QT_MOC_LITERAL(48, 660, 18), // "WorksheetTextItem*"
QT_MOC_LITERAL(49, 679, 11), // "rehighlight"
QT_MOC_LITERAL(50, 691, 18), // "enableHighlighting"
QT_MOC_LITERAL(51, 710, 9), // "highlight"
QT_MOC_LITERAL(52, 720, 16), // "enableCompletion"
QT_MOC_LITERAL(53, 737, 6), // "enable"
QT_MOC_LITERAL(54, 744, 25), // "enableExpressionNumbering"
QT_MOC_LITERAL(55, 770, 16), // "enableAnimations"
QT_MOC_LITERAL(56, 787, 5), // "toXML"
QT_MOC_LITERAL(57, 793, 12), // "QDomDocument"
QT_MOC_LITERAL(58, 806, 5), // "KZip*"
QT_MOC_LITERAL(59, 812, 7), // "archive"
QT_MOC_LITERAL(60, 820, 4), // "save"
QT_MOC_LITERAL(61, 825, 8), // "filename"
QT_MOC_LITERAL(62, 834, 10), // "QIODevice*"
QT_MOC_LITERAL(63, 845, 6), // "device"
QT_MOC_LITERAL(64, 852, 15), // "saveToByteArray"
QT_MOC_LITERAL(65, 868, 9), // "savePlain"
QT_MOC_LITERAL(66, 878, 9), // "saveLatex"
QT_MOC_LITERAL(67, 888, 4), // "load"
QT_MOC_LITERAL(68, 893, 11), // "QByteArray*"
QT_MOC_LITERAL(69, 905, 4), // "data"
QT_MOC_LITERAL(70, 910, 9), // "gotResult"
QT_MOC_LITERAL(71, 920, 19), // "Cantor::Expression*"
QT_MOC_LITERAL(72, 940, 4), // "expr"
QT_MOC_LITERAL(73, 945, 18), // "removeCurrentEntry"
QT_MOC_LITERAL(74, 964, 13), // "setFirstEntry"
QT_MOC_LITERAL(75, 978, 12), // "setLastEntry"
QT_MOC_LITERAL(76, 991, 20), // "invalidateFirstEntry"
QT_MOC_LITERAL(77, 1012, 19), // "invalidateLastEntry"
QT_MOC_LITERAL(78, 1032, 21), // "updateFocusedTextItem"
QT_MOC_LITERAL(79, 1054, 4), // "item"
QT_MOC_LITERAL(80, 1059, 21), // "updateDragScrollTimer"
QT_MOC_LITERAL(81, 1081, 16), // "registerShortcut"
QT_MOC_LITERAL(82, 1098, 8), // "QAction*"
QT_MOC_LITERAL(83, 1107, 14), // "updateShortcut"
QT_MOC_LITERAL(84, 1122, 22), // "setRichTextInformation"
QT_MOC_LITERAL(85, 1145, 12), // "RichTextInfo"
QT_MOC_LITERAL(86, 1158, 17), // "setAcceptRichText"
QT_MOC_LITERAL(87, 1176, 1), // "b"
QT_MOC_LITERAL(88, 1178, 22), // "setTextForegroundColor"
QT_MOC_LITERAL(89, 1201, 22), // "setTextBackgroundColor"
QT_MOC_LITERAL(90, 1224, 11), // "setTextBold"
QT_MOC_LITERAL(91, 1236, 13), // "setTextItalic"
QT_MOC_LITERAL(92, 1250, 16), // "setTextUnderline"
QT_MOC_LITERAL(93, 1267, 16), // "setTextStrikeOut"
QT_MOC_LITERAL(94, 1284, 12), // "setAlignLeft"
QT_MOC_LITERAL(95, 1297, 13), // "setAlignRight"
QT_MOC_LITERAL(96, 1311, 14), // "setAlignCenter"
QT_MOC_LITERAL(97, 1326, 15), // "setAlignJustify"
QT_MOC_LITERAL(98, 1342, 13), // "setFontFamily"
QT_MOC_LITERAL(99, 1356, 4), // "font"
QT_MOC_LITERAL(100, 1361, 11), // "setFontSize"
QT_MOC_LITERAL(101, 1373, 4), // "size"
QT_MOC_LITERAL(102, 1378, 14), // "loginToSession"
QT_MOC_LITERAL(103, 1393, 14), // "showCompletion"
QT_MOC_LITERAL(104, 1408, 11), // "appendEntry"
QT_MOC_LITERAL(105, 1420, 4), // "type"
QT_MOC_LITERAL(106, 1425, 11), // "insertEntry"
QT_MOC_LITERAL(107, 1437, 17) // "insertEntryBefore"

    },
    "Worksheet\0modified\0\0sessionChanged\0"
    "showHelp\0help\0updatePrompt\0undoAvailable\0"
    "redoAvailable\0undo\0redo\0cutAvailable\0"
    "copyAvailable\0pasteAvailable\0cut\0copy\0"
    "paste\0appendCommandEntry\0WorksheetEntry*\0"
    "text\0appendTextEntry\0appendImageEntry\0"
    "appendPageBreakEntry\0appendLatexEntry\0"
    "insertCommandEntry\0current\0insertTextEntry\0"
    "insertImageEntry\0insertPageBreakEntry\0"
    "insertLatexEntry\0insertCommandEntryBefore\0"
    "insertTextEntryBefore\0insertImageEntryBefore\0"
    "insertPageBreakEntryBefore\0"
    "insertLatexEntryBefore\0updateLayout\0"
    "updateEntrySize\0entry\0print\0QPrinter*\0"
    "printer\0focusEntry\0evaluate\0"
    "evaluateCurrentEntry\0interrupt\0"
    "interruptCurrentEntryEvaluation\0"
    "completionEnabled\0highlightItem\0"
    "WorksheetTextItem*\0rehighlight\0"
    "enableHighlighting\0highlight\0"
    "enableCompletion\0enable\0"
    "enableExpressionNumbering\0enableAnimations\0"
    "toXML\0QDomDocument\0KZip*\0archive\0save\0"
    "filename\0QIODevice*\0device\0saveToByteArray\0"
    "savePlain\0saveLatex\0load\0QByteArray*\0"
    "data\0gotResult\0Cantor::Expression*\0"
    "expr\0removeCurrentEntry\0setFirstEntry\0"
    "setLastEntry\0invalidateFirstEntry\0"
    "invalidateLastEntry\0updateFocusedTextItem\0"
    "item\0updateDragScrollTimer\0registerShortcut\0"
    "QAction*\0updateShortcut\0setRichTextInformation\0"
    "RichTextInfo\0setAcceptRichText\0b\0"
    "setTextForegroundColor\0setTextBackgroundColor\0"
    "setTextBold\0setTextItalic\0setTextUnderline\0"
    "setTextStrikeOut\0setAlignLeft\0"
    "setAlignRight\0setAlignCenter\0"
    "setAlignJustify\0setFontFamily\0font\0"
    "setFontSize\0size\0loginToSession\0"
    "showCompletion\0appendEntry\0type\0"
    "insertEntry\0insertEntryBefore"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Worksheet[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      98,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      14,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  504,    2, 0x06 /* Public */,
       3,    0,  505,    2, 0x06 /* Public */,
       4,    1,  506,    2, 0x06 /* Public */,
       6,    0,  509,    2, 0x06 /* Public */,
       7,    1,  510,    2, 0x06 /* Public */,
       8,    1,  513,    2, 0x06 /* Public */,
       9,    0,  516,    2, 0x06 /* Public */,
      10,    0,  517,    2, 0x06 /* Public */,
      11,    1,  518,    2, 0x06 /* Public */,
      12,    1,  521,    2, 0x06 /* Public */,
      13,    1,  524,    2, 0x06 /* Public */,
      14,    0,  527,    2, 0x06 /* Public */,
      15,    0,  528,    2, 0x06 /* Public */,
      16,    0,  529,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      17,    0,  530,    2, 0x0a /* Public */,
      17,    1,  531,    2, 0x0a /* Public */,
      20,    0,  534,    2, 0x0a /* Public */,
      21,    0,  535,    2, 0x0a /* Public */,
      22,    0,  536,    2, 0x0a /* Public */,
      23,    0,  537,    2, 0x0a /* Public */,
      24,    1,  538,    2, 0x0a /* Public */,
      24,    0,  541,    2, 0x2a /* Public | MethodCloned */,
      24,    1,  542,    2, 0x0a /* Public */,
      26,    1,  545,    2, 0x0a /* Public */,
      26,    0,  548,    2, 0x2a /* Public | MethodCloned */,
      27,    1,  549,    2, 0x0a /* Public */,
      27,    0,  552,    2, 0x2a /* Public | MethodCloned */,
      28,    1,  553,    2, 0x0a /* Public */,
      28,    0,  556,    2, 0x2a /* Public | MethodCloned */,
      29,    1,  557,    2, 0x0a /* Public */,
      29,    0,  560,    2, 0x2a /* Public | MethodCloned */,
      30,    1,  561,    2, 0x0a /* Public */,
      30,    0,  564,    2, 0x2a /* Public | MethodCloned */,
      31,    1,  565,    2, 0x0a /* Public */,
      31,    0,  568,    2, 0x2a /* Public | MethodCloned */,
      32,    1,  569,    2, 0x0a /* Public */,
      32,    0,  572,    2, 0x2a /* Public | MethodCloned */,
      33,    1,  573,    2, 0x0a /* Public */,
      33,    0,  576,    2, 0x2a /* Public | MethodCloned */,
      34,    1,  577,    2, 0x0a /* Public */,
      34,    0,  580,    2, 0x2a /* Public | MethodCloned */,
      35,    0,  581,    2, 0x0a /* Public */,
      36,    1,  582,    2, 0x0a /* Public */,
      38,    1,  585,    2, 0x0a /* Public */,
      41,    1,  588,    2, 0x0a /* Public */,
      42,    0,  591,    2, 0x0a /* Public */,
      43,    0,  592,    2, 0x0a /* Public */,
      44,    0,  593,    2, 0x0a /* Public */,
      45,    0,  594,    2, 0x0a /* Public */,
      46,    0,  595,    2, 0x0a /* Public */,
      47,    1,  596,    2, 0x0a /* Public */,
      49,    0,  599,    2, 0x0a /* Public */,
      50,    1,  600,    2, 0x0a /* Public */,
      52,    1,  603,    2, 0x0a /* Public */,
      54,    1,  606,    2, 0x0a /* Public */,
      55,    1,  609,    2, 0x0a /* Public */,
      56,    1,  612,    2, 0x0a /* Public */,
      56,    0,  615,    2, 0x2a /* Public | MethodCloned */,
      60,    1,  616,    2, 0x0a /* Public */,
      60,    1,  619,    2, 0x0a /* Public */,
      64,    0,  622,    2, 0x0a /* Public */,
      65,    1,  623,    2, 0x0a /* Public */,
      66,    1,  626,    2, 0x0a /* Public */,
      67,    1,  629,    2, 0x0a /* Public */,
      67,    1,  632,    2, 0x0a /* Public */,
      67,    1,  635,    2, 0x0a /* Public */,
      70,    1,  638,    2, 0x0a /* Public */,
      70,    0,  641,    2, 0x2a /* Public | MethodCloned */,
      73,    0,  642,    2, 0x0a /* Public */,
      74,    1,  643,    2, 0x0a /* Public */,
      75,    1,  646,    2, 0x0a /* Public */,
      76,    0,  649,    2, 0x0a /* Public */,
      77,    0,  650,    2, 0x0a /* Public */,
      78,    1,  651,    2, 0x0a /* Public */,
      80,    0,  654,    2, 0x0a /* Public */,
      81,    1,  655,    2, 0x0a /* Public */,
      83,    0,  658,    2, 0x0a /* Public */,
      84,    1,  659,    2, 0x0a /* Public */,
      86,    1,  662,    2, 0x0a /* Public */,
      88,    0,  665,    2, 0x0a /* Public */,
      89,    0,  666,    2, 0x0a /* Public */,
      90,    1,  667,    2, 0x0a /* Public */,
      91,    1,  670,    2, 0x0a /* Public */,
      92,    1,  673,    2, 0x0a /* Public */,
      93,    1,  676,    2, 0x0a /* Public */,
      94,    0,  679,    2, 0x0a /* Public */,
      95,    0,  680,    2, 0x0a /* Public */,
      96,    0,  681,    2, 0x0a /* Public */,
      97,    0,  682,    2, 0x0a /* Public */,
      98,    1,  683,    2, 0x0a /* Public */,
     100,    1,  686,    2, 0x0a /* Public */,
     102,    0,  689,    2, 0x08 /* Private */,
     103,    0,  690,    2, 0x08 /* Private */,
     104,    1,  691,    2, 0x08 /* Private */,
     106,    2,  694,    2, 0x08 /* Private */,
     106,    1,  699,    2, 0x28 /* Private | MethodCloned */,
     107,    2,  702,    2, 0x08 /* Private */,
     107,    1,  707,    2, 0x28 /* Private | MethodCloned */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    0x80000000 | 18,
    QMetaType::Void, QMetaType::QString,   19,
    0x80000000 | 18,
    0x80000000 | 18,
    0x80000000 | 18,
    0x80000000 | 18,
    0x80000000 | 18, 0x80000000 | 18,   25,
    0x80000000 | 18,
    QMetaType::Void, QMetaType::QString,   19,
    0x80000000 | 18, 0x80000000 | 18,   25,
    0x80000000 | 18,
    0x80000000 | 18, 0x80000000 | 18,   25,
    0x80000000 | 18,
    0x80000000 | 18, 0x80000000 | 18,   25,
    0x80000000 | 18,
    0x80000000 | 18, 0x80000000 | 18,   25,
    0x80000000 | 18,
    0x80000000 | 18, 0x80000000 | 18,   25,
    0x80000000 | 18,
    0x80000000 | 18, 0x80000000 | 18,   25,
    0x80000000 | 18,
    0x80000000 | 18, 0x80000000 | 18,   25,
    0x80000000 | 18,
    0x80000000 | 18, 0x80000000 | 18,   25,
    0x80000000 | 18,
    0x80000000 | 18, 0x80000000 | 18,   25,
    0x80000000 | 18,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 18,   37,
    QMetaType::Void, 0x80000000 | 39,   40,
    QMetaType::Void, 0x80000000 | 18,   37,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void, 0x80000000 | 48,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   51,
    QMetaType::Void, QMetaType::Bool,   53,
    QMetaType::Void, QMetaType::Bool,   53,
    QMetaType::Void, QMetaType::Bool,   53,
    0x80000000 | 57, 0x80000000 | 58,   59,
    0x80000000 | 57,
    QMetaType::Void, QMetaType::QString,   61,
    QMetaType::Void, 0x80000000 | 62,   63,
    QMetaType::QByteArray,
    QMetaType::Void, QMetaType::QString,   61,
    QMetaType::Void, QMetaType::QString,   61,
    QMetaType::Void, 0x80000000 | 62,   63,
    QMetaType::Void, 0x80000000 | 68,   69,
    QMetaType::Void, QMetaType::QString,   61,
    QMetaType::Void, 0x80000000 | 71,   72,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 18,   37,
    QMetaType::Void, 0x80000000 | 18,   37,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 48,   79,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 82,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 85,    2,
    QMetaType::Void, QMetaType::Bool,   87,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   87,
    QMetaType::Void, QMetaType::Bool,   87,
    QMetaType::Void, QMetaType::Bool,   87,
    QMetaType::Void, QMetaType::Bool,   87,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   99,
    QMetaType::Void, QMetaType::Int,  101,
    QMetaType::Void,
    QMetaType::Void,
    0x80000000 | 18, QMetaType::Int,  105,
    0x80000000 | 18, QMetaType::Int, 0x80000000 | 18,  105,   25,
    0x80000000 | 18, QMetaType::Int,  105,
    0x80000000 | 18, QMetaType::Int, 0x80000000 | 18,  105,   25,
    0x80000000 | 18, QMetaType::Int,  105,

       0        // eod
};

void Worksheet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Worksheet *_t = static_cast<Worksheet *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->modified(); break;
        case 1: _t->sessionChanged(); break;
        case 2: _t->showHelp((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->updatePrompt(); break;
        case 4: _t->undoAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->redoAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->undo(); break;
        case 7: _t->redo(); break;
        case 8: _t->cutAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->copyAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->pasteAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->cut(); break;
        case 12: _t->copy(); break;
        case 13: _t->paste(); break;
        case 14: { WorksheetEntry* _r = _t->appendCommandEntry();
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 15: _t->appendCommandEntry((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 16: { WorksheetEntry* _r = _t->appendTextEntry();
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 17: { WorksheetEntry* _r = _t->appendImageEntry();
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 18: { WorksheetEntry* _r = _t->appendPageBreakEntry();
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 19: { WorksheetEntry* _r = _t->appendLatexEntry();
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 20: { WorksheetEntry* _r = _t->insertCommandEntry((*reinterpret_cast< WorksheetEntry*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 21: { WorksheetEntry* _r = _t->insertCommandEntry();
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 22: _t->insertCommandEntry((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 23: { WorksheetEntry* _r = _t->insertTextEntry((*reinterpret_cast< WorksheetEntry*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 24: { WorksheetEntry* _r = _t->insertTextEntry();
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 25: { WorksheetEntry* _r = _t->insertImageEntry((*reinterpret_cast< WorksheetEntry*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 26: { WorksheetEntry* _r = _t->insertImageEntry();
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 27: { WorksheetEntry* _r = _t->insertPageBreakEntry((*reinterpret_cast< WorksheetEntry*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 28: { WorksheetEntry* _r = _t->insertPageBreakEntry();
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 29: { WorksheetEntry* _r = _t->insertLatexEntry((*reinterpret_cast< WorksheetEntry*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 30: { WorksheetEntry* _r = _t->insertLatexEntry();
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 31: { WorksheetEntry* _r = _t->insertCommandEntryBefore((*reinterpret_cast< WorksheetEntry*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 32: { WorksheetEntry* _r = _t->insertCommandEntryBefore();
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 33: { WorksheetEntry* _r = _t->insertTextEntryBefore((*reinterpret_cast< WorksheetEntry*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 34: { WorksheetEntry* _r = _t->insertTextEntryBefore();
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 35: { WorksheetEntry* _r = _t->insertImageEntryBefore((*reinterpret_cast< WorksheetEntry*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 36: { WorksheetEntry* _r = _t->insertImageEntryBefore();
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 37: { WorksheetEntry* _r = _t->insertPageBreakEntryBefore((*reinterpret_cast< WorksheetEntry*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 38: { WorksheetEntry* _r = _t->insertPageBreakEntryBefore();
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 39: { WorksheetEntry* _r = _t->insertLatexEntryBefore((*reinterpret_cast< WorksheetEntry*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 40: { WorksheetEntry* _r = _t->insertLatexEntryBefore();
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 41: _t->updateLayout(); break;
        case 42: _t->updateEntrySize((*reinterpret_cast< WorksheetEntry*(*)>(_a[1]))); break;
        case 43: _t->print((*reinterpret_cast< QPrinter*(*)>(_a[1]))); break;
        case 44: _t->focusEntry((*reinterpret_cast< WorksheetEntry*(*)>(_a[1]))); break;
        case 45: _t->evaluate(); break;
        case 46: _t->evaluateCurrentEntry(); break;
        case 47: _t->interrupt(); break;
        case 48: _t->interruptCurrentEntryEvaluation(); break;
        case 49: { bool _r = _t->completionEnabled();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 50: _t->highlightItem((*reinterpret_cast< WorksheetTextItem*(*)>(_a[1]))); break;
        case 51: _t->rehighlight(); break;
        case 52: _t->enableHighlighting((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 53: _t->enableCompletion((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 54: _t->enableExpressionNumbering((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 55: _t->enableAnimations((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 56: { QDomDocument _r = _t->toXML((*reinterpret_cast< KZip*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDomDocument*>(_a[0]) = std::move(_r); }  break;
        case 57: { QDomDocument _r = _t->toXML();
            if (_a[0]) *reinterpret_cast< QDomDocument*>(_a[0]) = std::move(_r); }  break;
        case 58: _t->save((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 59: _t->save((*reinterpret_cast< QIODevice*(*)>(_a[1]))); break;
        case 60: { QByteArray _r = _t->saveToByteArray();
            if (_a[0]) *reinterpret_cast< QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 61: _t->savePlain((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 62: _t->saveLatex((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 63: _t->load((*reinterpret_cast< QIODevice*(*)>(_a[1]))); break;
        case 64: _t->load((*reinterpret_cast< QByteArray*(*)>(_a[1]))); break;
        case 65: _t->load((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 66: _t->gotResult((*reinterpret_cast< Cantor::Expression*(*)>(_a[1]))); break;
        case 67: _t->gotResult(); break;
        case 68: _t->removeCurrentEntry(); break;
        case 69: _t->setFirstEntry((*reinterpret_cast< WorksheetEntry*(*)>(_a[1]))); break;
        case 70: _t->setLastEntry((*reinterpret_cast< WorksheetEntry*(*)>(_a[1]))); break;
        case 71: _t->invalidateFirstEntry(); break;
        case 72: _t->invalidateLastEntry(); break;
        case 73: _t->updateFocusedTextItem((*reinterpret_cast< WorksheetTextItem*(*)>(_a[1]))); break;
        case 74: _t->updateDragScrollTimer(); break;
        case 75: _t->registerShortcut((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 76: _t->updateShortcut(); break;
        case 77: _t->setRichTextInformation((*reinterpret_cast< const RichTextInfo(*)>(_a[1]))); break;
        case 78: _t->setAcceptRichText((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 79: _t->setTextForegroundColor(); break;
        case 80: _t->setTextBackgroundColor(); break;
        case 81: _t->setTextBold((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 82: _t->setTextItalic((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 83: _t->setTextUnderline((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 84: _t->setTextStrikeOut((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 85: _t->setAlignLeft(); break;
        case 86: _t->setAlignRight(); break;
        case 87: _t->setAlignCenter(); break;
        case 88: _t->setAlignJustify(); break;
        case 89: _t->setFontFamily((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 90: _t->setFontSize((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 91: _t->loginToSession(); break;
        case 92: _t->showCompletion(); break;
        case 93: { WorksheetEntry* _r = _t->appendEntry((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 94: { WorksheetEntry* _r = _t->insertEntry((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< WorksheetEntry*(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 95: { WorksheetEntry* _r = _t->insertEntry((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 96: { WorksheetEntry* _r = _t->insertEntryBefore((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< WorksheetEntry*(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        case 97: { WorksheetEntry* _r = _t->insertEntryBefore((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< WorksheetEntry**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 59:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QIODevice* >(); break;
            }
            break;
        case 63:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QIODevice* >(); break;
            }
            break;
        case 75:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (Worksheet::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Worksheet::modified)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Worksheet::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Worksheet::sessionChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Worksheet::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Worksheet::showHelp)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Worksheet::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Worksheet::updatePrompt)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Worksheet::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Worksheet::undoAvailable)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Worksheet::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Worksheet::redoAvailable)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Worksheet::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Worksheet::undo)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (Worksheet::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Worksheet::redo)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (Worksheet::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Worksheet::cutAvailable)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (Worksheet::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Worksheet::copyAvailable)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (Worksheet::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Worksheet::pasteAvailable)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (Worksheet::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Worksheet::cut)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (Worksheet::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Worksheet::copy)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (Worksheet::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Worksheet::paste)) {
                *result = 13;
                return;
            }
        }
    }
}

const QMetaObject Worksheet::staticMetaObject = {
    { &QGraphicsScene::staticMetaObject, qt_meta_stringdata_Worksheet.data,
      qt_meta_data_Worksheet,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Worksheet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Worksheet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Worksheet.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsScene::qt_metacast(_clname);
}

int Worksheet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsScene::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 98)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 98;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 98)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 98;
    }
    return _id;
}

// SIGNAL 0
void Worksheet::modified()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Worksheet::sessionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Worksheet::showHelp(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Worksheet::updatePrompt()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Worksheet::undoAvailable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Worksheet::redoAvailable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Worksheet::undo()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Worksheet::redo()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Worksheet::cutAvailable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Worksheet::copyAvailable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void Worksheet::pasteAvailable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void Worksheet::cut()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Worksheet::copy()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Worksheet::paste()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
