// This file is generated by kconfig_compiler_kf5 from cantor.kcfg.
// All changes you do to this file will be lost.

#include "settings.h"

#include <qglobal.h>
#include <QtCore/QFile>

class SettingsHelper
{
  public:
    SettingsHelper() : q(nullptr) {}
    ~SettingsHelper() { delete q; }
    Settings *q;
};
Q_GLOBAL_STATIC(SettingsHelper, s_globalSettings)
Settings *Settings::self()
{
  if (!s_globalSettings()->q) {
    new Settings;
    s_globalSettings()->q->read();
  }

  return s_globalSettings()->q;
}

Settings::Settings(  )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalSettings()->q);
  s_globalSettings()->q = this;
  setCurrentGroup( QStringLiteral( "Cantor" ) );

  KConfigSkeleton::ItemString  *itemDefaultBackend;
  itemDefaultBackend = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DefaultBackend" ), mDefaultBackend );
  addItem( itemDefaultBackend, QStringLiteral( "DefaultBackend" ) );
  KConfigSkeleton::ItemBool  *itemTypesetDefault;
  itemTypesetDefault = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TypesetDefault" ), mTypesetDefault, true );
  addItem( itemTypesetDefault, QStringLiteral( "TypesetDefault" ) );
  KConfigSkeleton::ItemBool  *itemHighlightDefault;
  itemHighlightDefault = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HighlightDefault" ), mHighlightDefault, true );
  addItem( itemHighlightDefault, QStringLiteral( "HighlightDefault" ) );
  KConfigSkeleton::ItemBool  *itemCompletionDefault;
  itemCompletionDefault = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CompletionDefault" ), mCompletionDefault, true );
  addItem( itemCompletionDefault, QStringLiteral( "CompletionDefault" ) );
  KConfigSkeleton::ItemBool  *itemExpressionNumberingDefault;
  itemExpressionNumberingDefault = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ExpressionNumberingDefault" ), mExpressionNumberingDefault, false );
  addItem( itemExpressionNumberingDefault, QStringLiteral( "ExpressionNumberingDefault" ) );
  KConfigSkeleton::ItemBool  *itemAnimationDefault;
  itemAnimationDefault = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnimationDefault" ), mAnimationDefault, true );
  addItem( itemAnimationDefault, QStringLiteral( "AnimationDefault" ) );
  KConfigSkeleton::ItemBool  *itemAutoEval;
  itemAutoEval = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoEval" ), mAutoEval, false );
  addItem( itemAutoEval, QStringLiteral( "AutoEval" ) );
}

Settings::~Settings()
{
  s_globalSettings()->q = nullptr;
}

