#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'differentiatedlg.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIFFERENTIATEDLG_H
#define UI_DIFFERENTIATEDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_DifferentiateAssistantBase
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout_2;
    QLabel *label;
    KLineEdit *expression;
    QLabel *label_2;
    KLineEdit *variable;
    QHBoxLayout *horizontalLayout;
    QLabel *label_3;
    QSpinBox *times;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *DifferentiateAssistantBase)
    {
        if (DifferentiateAssistantBase->objectName().isEmpty())
            DifferentiateAssistantBase->setObjectName(QStringLiteral("DifferentiateAssistantBase"));
        DifferentiateAssistantBase->resize(400, 300);
        verticalLayout = new QVBoxLayout(DifferentiateAssistantBase);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        label = new QLabel(DifferentiateAssistantBase);
        label->setObjectName(QStringLiteral("label"));

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        expression = new KLineEdit(DifferentiateAssistantBase);
        expression->setObjectName(QStringLiteral("expression"));

        gridLayout_2->addWidget(expression, 0, 1, 1, 1);

        label_2 = new QLabel(DifferentiateAssistantBase);
        label_2->setObjectName(QStringLiteral("label_2"));

        gridLayout_2->addWidget(label_2, 1, 0, 1, 1);

        variable = new KLineEdit(DifferentiateAssistantBase);
        variable->setObjectName(QStringLiteral("variable"));

        gridLayout_2->addWidget(variable, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label_3 = new QLabel(DifferentiateAssistantBase);
        label_3->setObjectName(QStringLiteral("label_3"));

        horizontalLayout->addWidget(label_3);

        times = new QSpinBox(DifferentiateAssistantBase);
        times->setObjectName(QStringLiteral("times"));
        times->setValue(1);

        horizontalLayout->addWidget(times);


        verticalLayout->addLayout(horizontalLayout);

        buttonBox = new QDialogButtonBox(DifferentiateAssistantBase);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(DifferentiateAssistantBase);

        QMetaObject::connectSlotsByName(DifferentiateAssistantBase);
    } // setupUi

    void retranslateUi(QWidget *DifferentiateAssistantBase)
    {
        label->setText(tr2i18n("Expression:", Q_NULLPTR));
        label_2->setText(tr2i18n("Variable:", Q_NULLPTR));
        variable->setText(tr2i18n("x", Q_NULLPTR));
        label_3->setText(tr2i18n("Times: ", Q_NULLPTR));
        Q_UNUSED(DifferentiateAssistantBase);
    } // retranslateUi

};

namespace Ui {
    class DifferentiateAssistantBase: public Ui_DifferentiateAssistantBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DIFFERENTIATEDLG_H

