/****************************************************************************
** Meta object code from reading C++ file 'scilabsession.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/cantor-17.08.3/src/backends/scilab/scilabsession.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scilabsession.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ScilabSession_t {
    QByteArrayData data[13];
    char stringdata0[202];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ScilabSession_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ScilabSession_t qt_meta_stringdata_ScilabSession = {
    {
QT_MOC_LITERAL(0, 0, 13), // "ScilabSession"
QT_MOC_LITERAL(1, 14, 17), // "updateHighlighter"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 25), // "updateVariableHighlighter"
QT_MOC_LITERAL(4, 59, 10), // "readOutput"
QT_MOC_LITERAL(5, 70, 9), // "readError"
QT_MOC_LITERAL(6, 80, 15), // "plotFileChanged"
QT_MOC_LITERAL(7, 96, 8), // "filename"
QT_MOC_LITERAL(8, 105, 18), // "expressionFinished"
QT_MOC_LITERAL(9, 124, 30), // "currentExpressionStatusChanged"
QT_MOC_LITERAL(10, 155, 26), // "Cantor::Expression::Status"
QT_MOC_LITERAL(11, 182, 6), // "status"
QT_MOC_LITERAL(12, 189, 12) // "listKeywords"

    },
    "ScilabSession\0updateHighlighter\0\0"
    "updateVariableHighlighter\0readOutput\0"
    "readError\0plotFileChanged\0filename\0"
    "expressionFinished\0currentExpressionStatusChanged\0"
    "Cantor::Expression::Status\0status\0"
    "listKeywords"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ScilabSession[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x06 /* Public */,
       3,    0,   55,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   56,    2, 0x0a /* Public */,
       5,    0,   57,    2, 0x0a /* Public */,
       6,    1,   58,    2, 0x0a /* Public */,
       8,    0,   61,    2, 0x08 /* Private */,
       9,    1,   62,    2, 0x08 /* Private */,
      12,    0,   65,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void,

       0        // eod
};

void ScilabSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ScilabSession *_t = static_cast<ScilabSession *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updateHighlighter(); break;
        case 1: _t->updateVariableHighlighter(); break;
        case 2: _t->readOutput(); break;
        case 3: _t->readError(); break;
        case 4: _t->plotFileChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 5: _t->expressionFinished(); break;
        case 6: _t->currentExpressionStatusChanged((*reinterpret_cast< Cantor::Expression::Status(*)>(_a[1]))); break;
        case 7: _t->listKeywords(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ScilabSession::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ScilabSession::updateHighlighter)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ScilabSession::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ScilabSession::updateVariableHighlighter)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject ScilabSession::staticMetaObject = {
    { &Cantor::Session::staticMetaObject, qt_meta_stringdata_ScilabSession.data,
      qt_meta_data_ScilabSession,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ScilabSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScilabSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ScilabSession.stringdata0))
        return static_cast<void*>(this);
    return Cantor::Session::qt_metacast(_clname);
}

int ScilabSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Cantor::Session::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void ScilabSession::updateHighlighter()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ScilabSession::updateVariableHighlighter()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
