/****************************************************************************
** Meta object code from reading C++ file 'imagesettingsdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/cantor-17.08.3/src/imagesettingsdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'imagesettingsdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ImageSettingsDialog_t {
    QByteArrayData data[15];
    char stringdata0[194];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ImageSettingsDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ImageSettingsDialog_t qt_meta_stringdata_ImageSettingsDialog = {
    {
QT_MOC_LITERAL(0, 0, 19), // "ImageSettingsDialog"
QT_MOC_LITERAL(1, 20, 11), // "dataChanged"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 4), // "file"
QT_MOC_LITERAL(4, 38, 9), // "ImageSize"
QT_MOC_LITERAL(5, 48, 11), // "displaySize"
QT_MOC_LITERAL(6, 60, 9), // "printSize"
QT_MOC_LITERAL(7, 70, 25), // "useDisplaySizeForPrinting"
QT_MOC_LITERAL(8, 96, 19), // "sendChangesAndClose"
QT_MOC_LITERAL(9, 116, 11), // "sendChanges"
QT_MOC_LITERAL(10, 128, 10), // "openDialog"
QT_MOC_LITERAL(11, 139, 13), // "updatePreview"
QT_MOC_LITERAL(12, 153, 18), // "updateInputWidgets"
QT_MOC_LITERAL(13, 172, 19), // "updatePrintingGroup"
QT_MOC_LITERAL(14, 192, 1) // "b"

    },
    "ImageSettingsDialog\0dataChanged\0\0file\0"
    "ImageSize\0displaySize\0printSize\0"
    "useDisplaySizeForPrinting\0sendChangesAndClose\0"
    "sendChanges\0openDialog\0updatePreview\0"
    "updateInputWidgets\0updatePrintingGroup\0"
    "b"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ImageSettingsDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    4,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,   58,    2, 0x08 /* Private */,
       9,    0,   59,    2, 0x08 /* Private */,
      10,    0,   60,    2, 0x08 /* Private */,
      11,    0,   61,    2, 0x08 /* Private */,
      12,    0,   62,    2, 0x08 /* Private */,
      13,    1,   63,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Bool,    3,    5,    6,    7,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   14,

       0        // eod
};

void ImageSettingsDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ImageSettingsDialog *_t = static_cast<ImageSettingsDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->dataChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const ImageSize(*)>(_a[2])),(*reinterpret_cast< const ImageSize(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 1: _t->sendChangesAndClose(); break;
        case 2: _t->sendChanges(); break;
        case 3: _t->openDialog(); break;
        case 4: _t->updatePreview(); break;
        case 5: _t->updateInputWidgets(); break;
        case 6: _t->updatePrintingGroup((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ImageSettingsDialog::*_t)(const QString & , const ImageSize & , const ImageSize & , bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ImageSettingsDialog::dataChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject ImageSettingsDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_ImageSettingsDialog.data,
      qt_meta_data_ImageSettingsDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ImageSettingsDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImageSettingsDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ImageSettingsDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int ImageSettingsDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ImageSettingsDialog::dataChanged(const QString & _t1, const ImageSize & _t2, const ImageSize & _t3, bool _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
