#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'integratedlg.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INTEGRATEDLG_H
#define UI_INTEGRATEDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_IntegrateAssistantBase
{
public:
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout_2;
    QLabel *label;
    KLineEdit *expression;
    QLabel *label_2;
    KLineEdit *variable;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label_3;
    KLineEdit *lowerLimit;
    QLabel *label_4;
    KLineEdit *upperLimit;
    QCheckBox *isDefinite;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *IntegrateAssistantBase)
    {
        if (IntegrateAssistantBase->objectName().isEmpty())
            IntegrateAssistantBase->setObjectName(QStringLiteral("IntegrateAssistantBase"));
        IntegrateAssistantBase->resize(400, 300);
        verticalLayout_2 = new QVBoxLayout(IntegrateAssistantBase);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        label = new QLabel(IntegrateAssistantBase);
        label->setObjectName(QStringLiteral("label"));

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        expression = new KLineEdit(IntegrateAssistantBase);
        expression->setObjectName(QStringLiteral("expression"));

        gridLayout_2->addWidget(expression, 0, 1, 1, 1);

        label_2 = new QLabel(IntegrateAssistantBase);
        label_2->setObjectName(QStringLiteral("label_2"));

        gridLayout_2->addWidget(label_2, 1, 0, 1, 1);

        variable = new KLineEdit(IntegrateAssistantBase);
        variable->setObjectName(QStringLiteral("variable"));

        gridLayout_2->addWidget(variable, 1, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout_2);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        label_3 = new QLabel(IntegrateAssistantBase);
        label_3->setObjectName(QStringLiteral("label_3"));

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        lowerLimit = new KLineEdit(IntegrateAssistantBase);
        lowerLimit->setObjectName(QStringLiteral("lowerLimit"));
        lowerLimit->setEnabled(false);

        gridLayout->addWidget(lowerLimit, 1, 1, 1, 1);

        label_4 = new QLabel(IntegrateAssistantBase);
        label_4->setObjectName(QStringLiteral("label_4"));

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        upperLimit = new KLineEdit(IntegrateAssistantBase);
        upperLimit->setObjectName(QStringLiteral("upperLimit"));
        upperLimit->setEnabled(false);

        gridLayout->addWidget(upperLimit, 2, 1, 1, 1);

        isDefinite = new QCheckBox(IntegrateAssistantBase);
        isDefinite->setObjectName(QStringLiteral("isDefinite"));

        gridLayout->addWidget(isDefinite, 0, 0, 1, 1);


        verticalLayout->addLayout(gridLayout);


        verticalLayout_2->addLayout(verticalLayout);

        buttonBox = new QDialogButtonBox(IntegrateAssistantBase);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(IntegrateAssistantBase);
        QObject::connect(isDefinite, SIGNAL(toggled(bool)), lowerLimit, SLOT(setEnabled(bool)));
        QObject::connect(isDefinite, SIGNAL(toggled(bool)), upperLimit, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(IntegrateAssistantBase);
    } // setupUi

    void retranslateUi(QWidget *IntegrateAssistantBase)
    {
        label->setText(tr2i18n("Expression:", Q_NULLPTR));
        label_2->setText(tr2i18n("Variable:", Q_NULLPTR));
        variable->setText(tr2i18n("x", Q_NULLPTR));
        label_3->setText(tr2i18n("Lower limit:", Q_NULLPTR));
        label_4->setText(tr2i18n("Upper limit:", Q_NULLPTR));
        isDefinite->setText(tr2i18n("definite integral", Q_NULLPTR));
        Q_UNUSED(IntegrateAssistantBase);
    } // retranslateUi

};

namespace Ui {
    class IntegrateAssistantBase: public Ui_IntegrateAssistantBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // INTEGRATEDLG_H

