/****************************************************************************
** Meta object code from reading C++ file 'worksheetentry.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/cantor-17.08.3/src/worksheetentry.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'worksheetentry.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_WorksheetEntry_t {
    QByteArrayData data[42];
    char stringdata0[598];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_WorksheetEntry_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_WorksheetEntry_t qt_meta_stringdata_WorksheetEntry = {
    {
QT_MOC_LITERAL(0, 0, 14), // "WorksheetEntry"
QT_MOC_LITERAL(1, 15, 16), // "aboutToBeDeleted"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 8), // "evaluate"
QT_MOC_LITERAL(4, 42, 16), // "EvaluationOption"
QT_MOC_LITERAL(5, 59, 6), // "evalOp"
QT_MOC_LITERAL(6, 66, 19), // "evaluateCurrentItem"
QT_MOC_LITERAL(7, 86, 11), // "updateEntry"
QT_MOC_LITERAL(8, 98, 18), // "insertCommandEntry"
QT_MOC_LITERAL(9, 117, 15), // "insertTextEntry"
QT_MOC_LITERAL(10, 133, 16), // "insertLatexEntry"
QT_MOC_LITERAL(11, 150, 16), // "insertImageEntry"
QT_MOC_LITERAL(12, 167, 20), // "insertPageBreakEntry"
QT_MOC_LITERAL(13, 188, 24), // "insertCommandEntryBefore"
QT_MOC_LITERAL(14, 213, 21), // "insertTextEntryBefore"
QT_MOC_LITERAL(15, 235, 22), // "insertLatexEntryBefore"
QT_MOC_LITERAL(16, 258, 22), // "insertImageEntryBefore"
QT_MOC_LITERAL(17, 281, 26), // "insertPageBreakEntryBefore"
QT_MOC_LITERAL(18, 308, 12), // "sizeAnimated"
QT_MOC_LITERAL(19, 321, 13), // "startRemoving"
QT_MOC_LITERAL(20, 335, 12), // "stopRemoving"
QT_MOC_LITERAL(21, 348, 19), // "moveToPreviousEntry"
QT_MOC_LITERAL(22, 368, 3), // "pos"
QT_MOC_LITERAL(23, 372, 1), // "x"
QT_MOC_LITERAL(24, 374, 15), // "moveToNextEntry"
QT_MOC_LITERAL(25, 390, 15), // "recalculateSize"
QT_MOC_LITERAL(26, 406, 17), // "animateSizeChange"
QT_MOC_LITERAL(27, 424, 10), // "fadeInItem"
QT_MOC_LITERAL(28, 435, 16), // "QGraphicsObject*"
QT_MOC_LITERAL(29, 452, 4), // "item"
QT_MOC_LITERAL(30, 457, 11), // "const char*"
QT_MOC_LITERAL(31, 469, 4), // "slot"
QT_MOC_LITERAL(32, 474, 11), // "fadeOutItem"
QT_MOC_LITERAL(33, 486, 12), // "endAnimation"
QT_MOC_LITERAL(34, 499, 13), // "showActionBar"
QT_MOC_LITERAL(35, 513, 13), // "hideActionBar"
QT_MOC_LITERAL(36, 527, 9), // "startDrag"
QT_MOC_LITERAL(37, 537, 7), // "grabPos"
QT_MOC_LITERAL(38, 545, 6), // "remove"
QT_MOC_LITERAL(39, 552, 15), // "deleteActionBar"
QT_MOC_LITERAL(40, 568, 24), // "deleteActionBarAnimation"
QT_MOC_LITERAL(41, 593, 4) // "size"

    },
    "WorksheetEntry\0aboutToBeDeleted\0\0"
    "evaluate\0EvaluationOption\0evalOp\0"
    "evaluateCurrentItem\0updateEntry\0"
    "insertCommandEntry\0insertTextEntry\0"
    "insertLatexEntry\0insertImageEntry\0"
    "insertPageBreakEntry\0insertCommandEntryBefore\0"
    "insertTextEntryBefore\0insertLatexEntryBefore\0"
    "insertImageEntryBefore\0"
    "insertPageBreakEntryBefore\0sizeAnimated\0"
    "startRemoving\0stopRemoving\0"
    "moveToPreviousEntry\0pos\0x\0moveToNextEntry\0"
    "recalculateSize\0animateSizeChange\0"
    "fadeInItem\0QGraphicsObject*\0item\0"
    "const char*\0slot\0fadeOutItem\0endAnimation\0"
    "showActionBar\0hideActionBar\0startDrag\0"
    "grabPos\0remove\0deleteActionBar\0"
    "deleteActionBarAnimation\0size"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_WorksheetEntry[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      40,   14, // methods
       1,  282, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  214,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,  215,    2, 0x0a /* Public */,
       3,    0,  218,    2, 0x2a /* Public | MethodCloned */,
       6,    0,  219,    2, 0x0a /* Public */,
       7,    0,  220,    2, 0x0a /* Public */,
       8,    0,  221,    2, 0x0a /* Public */,
       9,    0,  222,    2, 0x0a /* Public */,
      10,    0,  223,    2, 0x0a /* Public */,
      11,    0,  224,    2, 0x0a /* Public */,
      12,    0,  225,    2, 0x0a /* Public */,
      13,    0,  226,    2, 0x0a /* Public */,
      14,    0,  227,    2, 0x0a /* Public */,
      15,    0,  228,    2, 0x0a /* Public */,
      16,    0,  229,    2, 0x0a /* Public */,
      17,    0,  230,    2, 0x0a /* Public */,
      18,    0,  231,    2, 0x0a /* Public */,
      19,    0,  232,    2, 0x0a /* Public */,
      20,    0,  233,    2, 0x0a /* Public */,
      21,    2,  234,    2, 0x0a /* Public */,
      21,    1,  239,    2, 0x2a /* Public | MethodCloned */,
      21,    0,  242,    2, 0x2a /* Public | MethodCloned */,
      24,    2,  243,    2, 0x0a /* Public */,
      24,    1,  248,    2, 0x2a /* Public | MethodCloned */,
      24,    0,  251,    2, 0x2a /* Public | MethodCloned */,
      25,    0,  252,    2, 0x0a /* Public */,
      26,    0,  253,    2, 0x0a /* Public */,
      27,    2,  254,    2, 0x0a /* Public */,
      27,    1,  259,    2, 0x2a /* Public | MethodCloned */,
      27,    0,  262,    2, 0x2a /* Public | MethodCloned */,
      32,    2,  263,    2, 0x0a /* Public */,
      32,    1,  268,    2, 0x2a /* Public | MethodCloned */,
      32,    0,  271,    2, 0x2a /* Public | MethodCloned */,
      33,    0,  272,    2, 0x0a /* Public */,
      34,    0,  273,    2, 0x0a /* Public */,
      35,    0,  274,    2, 0x0a /* Public */,
      36,    1,  275,    2, 0x0a /* Public */,
      36,    0,  278,    2, 0x2a /* Public | MethodCloned */,
      38,    0,  279,    2, 0x09 /* Protected */,
      39,    0,  280,    2, 0x09 /* Protected */,
      40,    0,  281,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Bool, 0x80000000 | 4,    5,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::Int, QMetaType::QReal,   22,   23,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QReal,   22,   23,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 28, 0x80000000 | 30,   29,   31,
    QMetaType::Void, 0x80000000 | 28,   29,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 28, 0x80000000 | 30,   29,   31,
    QMetaType::Void, 0x80000000 | 28,   29,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPointF,   37,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      41, QMetaType::QSizeF, 0x00095103,

       0        // eod
};

void WorksheetEntry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        WorksheetEntry *_t = static_cast<WorksheetEntry *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->aboutToBeDeleted(); break;
        case 1: { bool _r = _t->evaluate((*reinterpret_cast< EvaluationOption(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->evaluate();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->evaluateCurrentItem();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->updateEntry(); break;
        case 5: _t->insertCommandEntry(); break;
        case 6: _t->insertTextEntry(); break;
        case 7: _t->insertLatexEntry(); break;
        case 8: _t->insertImageEntry(); break;
        case 9: _t->insertPageBreakEntry(); break;
        case 10: _t->insertCommandEntryBefore(); break;
        case 11: _t->insertTextEntryBefore(); break;
        case 12: _t->insertLatexEntryBefore(); break;
        case 13: _t->insertImageEntryBefore(); break;
        case 14: _t->insertPageBreakEntryBefore(); break;
        case 15: _t->sizeAnimated(); break;
        case 16: _t->startRemoving(); break;
        case 17: { bool _r = _t->stopRemoving();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->moveToPreviousEntry((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 19: _t->moveToPreviousEntry((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 20: _t->moveToPreviousEntry(); break;
        case 21: _t->moveToNextEntry((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 22: _t->moveToNextEntry((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 23: _t->moveToNextEntry(); break;
        case 24: _t->recalculateSize(); break;
        case 25: _t->animateSizeChange(); break;
        case 26: _t->fadeInItem((*reinterpret_cast< QGraphicsObject*(*)>(_a[1])),(*reinterpret_cast< const char*(*)>(_a[2]))); break;
        case 27: _t->fadeInItem((*reinterpret_cast< QGraphicsObject*(*)>(_a[1]))); break;
        case 28: _t->fadeInItem(); break;
        case 29: _t->fadeOutItem((*reinterpret_cast< QGraphicsObject*(*)>(_a[1])),(*reinterpret_cast< const char*(*)>(_a[2]))); break;
        case 30: _t->fadeOutItem((*reinterpret_cast< QGraphicsObject*(*)>(_a[1]))); break;
        case 31: _t->fadeOutItem(); break;
        case 32: _t->endAnimation(); break;
        case 33: _t->showActionBar(); break;
        case 34: _t->hideActionBar(); break;
        case 35: _t->startDrag((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 36: _t->startDrag(); break;
        case 37: _t->remove(); break;
        case 38: _t->deleteActionBar(); break;
        case 39: _t->deleteActionBarAnimation(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QGraphicsObject* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QGraphicsObject* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QGraphicsObject* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QGraphicsObject* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (WorksheetEntry::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetEntry::aboutToBeDeleted)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        WorksheetEntry *_t = static_cast<WorksheetEntry *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QSizeF*>(_v) = _t->size(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        WorksheetEntry *_t = static_cast<WorksheetEntry *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSize(*reinterpret_cast< QSizeF*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject WorksheetEntry::staticMetaObject = {
    { &QGraphicsObject::staticMetaObject, qt_meta_stringdata_WorksheetEntry.data,
      qt_meta_data_WorksheetEntry,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *WorksheetEntry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WorksheetEntry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_WorksheetEntry.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsObject::qt_metacast(_clname);
}

int WorksheetEntry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void WorksheetEntry::aboutToBeDeleted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
