/****************************************************************************
** Meta object code from reading C++ file 'maximavariablemodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/cantor-17.08.3/src/backends/maxima/maximavariablemodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'maximavariablemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MaximaVariableModel_t {
    QByteArrayData data[11];
    char stringdata0[173];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MaximaVariableModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MaximaVariableModel_t qt_meta_stringdata_MaximaVariableModel = {
    {
QT_MOC_LITERAL(0, 0, 19), // "MaximaVariableModel"
QT_MOC_LITERAL(1, 20, 14), // "variablesAdded"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 9), // "variables"
QT_MOC_LITERAL(4, 46, 16), // "variablesRemoved"
QT_MOC_LITERAL(5, 63, 14), // "functionsAdded"
QT_MOC_LITERAL(6, 78, 16), // "functionsRemoved"
QT_MOC_LITERAL(7, 95, 20), // "checkForNewVariables"
QT_MOC_LITERAL(8, 116, 20), // "checkForNewFunctions"
QT_MOC_LITERAL(9, 137, 17), // "parseNewVariables"
QT_MOC_LITERAL(10, 155, 17) // "parseNewFunctions"

    },
    "MaximaVariableModel\0variablesAdded\0\0"
    "variables\0variablesRemoved\0functionsAdded\0"
    "functionsRemoved\0checkForNewVariables\0"
    "checkForNewFunctions\0parseNewVariables\0"
    "parseNewFunctions"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MaximaVariableModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       4,    1,   57,    2, 0x06 /* Public */,
       5,    1,   60,    2, 0x06 /* Public */,
       6,    1,   63,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   66,    2, 0x0a /* Public */,
       8,    0,   67,    2, 0x0a /* Public */,
       9,    0,   68,    2, 0x08 /* Private */,
      10,    0,   69,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QStringList,    3,
    QMetaType::Void, QMetaType::QStringList,    3,
    QMetaType::Void, QMetaType::QStringList,    3,
    QMetaType::Void, QMetaType::QStringList,    3,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void MaximaVariableModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MaximaVariableModel *_t = static_cast<MaximaVariableModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->variablesAdded((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 1: _t->variablesRemoved((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 2: _t->functionsAdded((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 3: _t->functionsRemoved((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 4: _t->checkForNewVariables(); break;
        case 5: _t->checkForNewFunctions(); break;
        case 6: _t->parseNewVariables(); break;
        case 7: _t->parseNewFunctions(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (MaximaVariableModel::*_t)(const QStringList );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MaximaVariableModel::variablesAdded)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (MaximaVariableModel::*_t)(const QStringList );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MaximaVariableModel::variablesRemoved)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (MaximaVariableModel::*_t)(const QStringList );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MaximaVariableModel::functionsAdded)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (MaximaVariableModel::*_t)(const QStringList );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MaximaVariableModel::functionsRemoved)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject MaximaVariableModel::staticMetaObject = {
    { &Cantor::DefaultVariableModel::staticMetaObject, qt_meta_stringdata_MaximaVariableModel.data,
      qt_meta_data_MaximaVariableModel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *MaximaVariableModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MaximaVariableModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MaximaVariableModel.stringdata0))
        return static_cast<void*>(this);
    return Cantor::DefaultVariableModel::qt_metacast(_clname);
}

int MaximaVariableModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Cantor::DefaultVariableModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void MaximaVariableModel::variablesAdded(const QStringList _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void MaximaVariableModel::variablesRemoved(const QStringList _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void MaximaVariableModel::functionsAdded(const QStringList _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void MaximaVariableModel::functionsRemoved(const QStringList _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
