#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_SettingsBase
{
public:
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    KComboBox *kcfg_DefaultBackend;
    QCheckBox *kcfg_AutoEval;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *kcfg_TypesetDefault;
    QCheckBox *kcfg_HighlightDefault;
    QCheckBox *kcfg_CompletionDefault;
    QCheckBox *kcfg_ExpressionNumberingDefault;
    QCheckBox *kcfg_AnimationDefault;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *SettingsBase)
    {
        if (SettingsBase->objectName().isEmpty())
            SettingsBase->setObjectName(QStringLiteral("SettingsBase"));
        SettingsBase->resize(398, 400);
        verticalLayout_3 = new QVBoxLayout(SettingsBase);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label = new QLabel(SettingsBase);
        label->setObjectName(QStringLiteral("label"));

        horizontalLayout->addWidget(label);

        kcfg_DefaultBackend = new KComboBox(SettingsBase);
        kcfg_DefaultBackend->setObjectName(QStringLiteral("kcfg_DefaultBackend"));
        kcfg_DefaultBackend->setEditable(true);

        horizontalLayout->addWidget(kcfg_DefaultBackend);


        verticalLayout_3->addLayout(horizontalLayout);

        kcfg_AutoEval = new QCheckBox(SettingsBase);
        kcfg_AutoEval->setObjectName(QStringLiteral("kcfg_AutoEval"));

        verticalLayout_3->addWidget(kcfg_AutoEval);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        groupBox = new QGroupBox(SettingsBase);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        kcfg_TypesetDefault = new QCheckBox(groupBox);
        kcfg_TypesetDefault->setObjectName(QStringLiteral("kcfg_TypesetDefault"));

        verticalLayout_2->addWidget(kcfg_TypesetDefault);

        kcfg_HighlightDefault = new QCheckBox(groupBox);
        kcfg_HighlightDefault->setObjectName(QStringLiteral("kcfg_HighlightDefault"));

        verticalLayout_2->addWidget(kcfg_HighlightDefault);

        kcfg_CompletionDefault = new QCheckBox(groupBox);
        kcfg_CompletionDefault->setObjectName(QStringLiteral("kcfg_CompletionDefault"));

        verticalLayout_2->addWidget(kcfg_CompletionDefault);

        kcfg_ExpressionNumberingDefault = new QCheckBox(groupBox);
        kcfg_ExpressionNumberingDefault->setObjectName(QStringLiteral("kcfg_ExpressionNumberingDefault"));

        verticalLayout_2->addWidget(kcfg_ExpressionNumberingDefault);

        kcfg_AnimationDefault = new QCheckBox(groupBox);
        kcfg_AnimationDefault->setObjectName(QStringLiteral("kcfg_AnimationDefault"));

        verticalLayout_2->addWidget(kcfg_AnimationDefault);


        verticalLayout->addWidget(groupBox);


        verticalLayout_3->addLayout(verticalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);


        retranslateUi(SettingsBase);

        QMetaObject::connectSlotsByName(SettingsBase);
    } // setupUi

    void retranslateUi(QWidget *SettingsBase)
    {
        label->setText(tr2i18n("Default Backend:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        kcfg_AutoEval->setToolTip(tr2i18n("When enabled, Cantor will automatically evaluate every entry below the current one.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        kcfg_AutoEval->setText(tr2i18n("Reevaluate Entries automatically", Q_NULLPTR));
        groupBox->setTitle(tr2i18n("Defaults", Q_NULLPTR));
        kcfg_TypesetDefault->setText(tr2i18n("Enable LaTeX Typesetting", Q_NULLPTR));
        kcfg_HighlightDefault->setText(tr2i18n("Enable Syntax Highlighting", Q_NULLPTR));
        kcfg_CompletionDefault->setText(tr2i18n("Enable Completion", Q_NULLPTR));
        kcfg_ExpressionNumberingDefault->setText(tr2i18n("Enable Line Numbers", Q_NULLPTR));
        kcfg_AnimationDefault->setText(tr2i18n("Enable Worksheet Animations", Q_NULLPTR));
        Q_UNUSED(SettingsBase);
    } // retranslateUi

};

namespace Ui {
    class SettingsBase: public Ui_SettingsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

