#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'imagesettings.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMAGESETTINGS_H
#define UI_IMAGESETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include "kcombobox.h"
#include "kimagefilepreview.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ImageSettingsBase
{
public:
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout_2;
    KLineEdit *pathEdit;
    QPushButton *openDialogButton;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label;
    QDoubleSpinBox *displayWidthInput;
    KComboBox *displayWidthCombo;
    QLabel *label_2;
    QDoubleSpinBox *displayHeightInput;
    KComboBox *displayHeightCombo;
    QGroupBox *gbPreview;
    QHBoxLayout *horizontalLayout;
    KImageFilePreview *imagePreview;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_2;
    QCheckBox *useDisplaySize;
    QLabel *label_5;
    QDoubleSpinBox *printWidthInput;
    KComboBox *printWidthCombo;
    QLabel *label_6;
    QDoubleSpinBox *printHeightInput;
    KComboBox *printHeightCombo;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *ImageSettingsBase)
    {
        if (ImageSettingsBase->objectName().isEmpty())
            ImageSettingsBase->setObjectName(QStringLiteral("ImageSettingsBase"));
        ImageSettingsBase->resize(586, 352);
        gridLayout_3 = new QGridLayout(ImageSettingsBase);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        pathEdit = new KLineEdit(ImageSettingsBase);
        pathEdit->setObjectName(QStringLiteral("pathEdit"));

        horizontalLayout_2->addWidget(pathEdit);

        openDialogButton = new QPushButton(ImageSettingsBase);
        openDialogButton->setObjectName(QStringLiteral("openDialogButton"));

        horizontalLayout_2->addWidget(openDialogButton);


        gridLayout_3->addLayout(horizontalLayout_2, 0, 0, 1, 2);

        groupBox = new QGroupBox(ImageSettingsBase);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        groupBox->setCheckable(false);
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        label = new QLabel(groupBox);
        label->setObjectName(QStringLiteral("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        displayWidthInput = new QDoubleSpinBox(groupBox);
        displayWidthInput->setObjectName(QStringLiteral("displayWidthInput"));

        gridLayout->addWidget(displayWidthInput, 0, 1, 1, 1);

        displayWidthCombo = new KComboBox(groupBox);
        displayWidthCombo->setObjectName(QStringLiteral("displayWidthCombo"));

        gridLayout->addWidget(displayWidthCombo, 0, 2, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QStringLiteral("label_2"));

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        displayHeightInput = new QDoubleSpinBox(groupBox);
        displayHeightInput->setObjectName(QStringLiteral("displayHeightInput"));

        gridLayout->addWidget(displayHeightInput, 1, 1, 1, 1);

        displayHeightCombo = new KComboBox(groupBox);
        displayHeightCombo->setObjectName(QStringLiteral("displayHeightCombo"));

        gridLayout->addWidget(displayHeightCombo, 1, 2, 1, 1);


        gridLayout_3->addWidget(groupBox, 1, 0, 1, 1);

        gbPreview = new QGroupBox(ImageSettingsBase);
        gbPreview->setObjectName(QStringLiteral("gbPreview"));
        horizontalLayout = new QHBoxLayout(gbPreview);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        imagePreview = new KImageFilePreview(gbPreview);
        imagePreview->setObjectName(QStringLiteral("imagePreview"));

        horizontalLayout->addWidget(imagePreview);


        gridLayout_3->addWidget(gbPreview, 1, 1, 2, 1);

        groupBox_2 = new QGroupBox(ImageSettingsBase);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        gridLayout_2 = new QGridLayout(groupBox_2);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        useDisplaySize = new QCheckBox(groupBox_2);
        useDisplaySize->setObjectName(QStringLiteral("useDisplaySize"));

        gridLayout_2->addWidget(useDisplaySize, 0, 0, 1, 2);

        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName(QStringLiteral("label_5"));

        gridLayout_2->addWidget(label_5, 1, 0, 1, 1);

        printWidthInput = new QDoubleSpinBox(groupBox_2);
        printWidthInput->setObjectName(QStringLiteral("printWidthInput"));

        gridLayout_2->addWidget(printWidthInput, 1, 1, 1, 1);

        printWidthCombo = new KComboBox(groupBox_2);
        printWidthCombo->setObjectName(QStringLiteral("printWidthCombo"));

        gridLayout_2->addWidget(printWidthCombo, 1, 2, 1, 1);

        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName(QStringLiteral("label_6"));

        gridLayout_2->addWidget(label_6, 2, 0, 1, 1);

        printHeightInput = new QDoubleSpinBox(groupBox_2);
        printHeightInput->setObjectName(QStringLiteral("printHeightInput"));

        gridLayout_2->addWidget(printHeightInput, 2, 1, 1, 1);

        printHeightCombo = new KComboBox(groupBox_2);
        printHeightCombo->setObjectName(QStringLiteral("printHeightCombo"));

        gridLayout_2->addWidget(printHeightCombo, 2, 2, 1, 1);


        gridLayout_3->addWidget(groupBox_2, 2, 0, 1, 1);

        buttonBox = new QDialogButtonBox(ImageSettingsBase);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout_3->addWidget(buttonBox, 3, 0, 1, 2);

        QWidget::setTabOrder(pathEdit, openDialogButton);
        QWidget::setTabOrder(openDialogButton, displayWidthInput);
        QWidget::setTabOrder(displayWidthInput, displayWidthCombo);
        QWidget::setTabOrder(displayWidthCombo, displayHeightInput);
        QWidget::setTabOrder(displayHeightInput, displayHeightCombo);
        QWidget::setTabOrder(displayHeightCombo, printWidthInput);
        QWidget::setTabOrder(printWidthInput, printWidthCombo);
        QWidget::setTabOrder(printWidthCombo, printHeightInput);
        QWidget::setTabOrder(printHeightInput, printHeightCombo);

        retranslateUi(ImageSettingsBase);

        QMetaObject::connectSlotsByName(ImageSettingsBase);
    } // setupUi

    void retranslateUi(QWidget *ImageSettingsBase)
    {
        ImageSettingsBase->setWindowTitle(tr2i18n("Image Settings", Q_NULLPTR));
        openDialogButton->setText(tr2i18n("Open", Q_NULLPTR));
        groupBox->setTitle(tr2i18n("Display Size", Q_NULLPTR));
        label->setText(tr2i18n("Width", Q_NULLPTR));
        label_2->setText(tr2i18n("Height", Q_NULLPTR));
        gbPreview->setTitle(tr2i18n("Preview", Q_NULLPTR));
        groupBox_2->setTitle(tr2i18n("Print Size", Q_NULLPTR));
        useDisplaySize->setText(tr2i18n("Use Display Size", Q_NULLPTR));
        label_5->setText(tr2i18n("Width", Q_NULLPTR));
        label_6->setText(tr2i18n("Height", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class ImageSettingsBase: public Ui_ImageSettingsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMAGESETTINGS_H

