/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p rserver_interface /usr/src/ports/cantor/cantor-17.08.3-1.x86_64/src/cantor-17.08.3/src/backends/R/rserver/org.kde.Cantor.R.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#include "rserver_interface.h"

/*
 * Implementation of interface class OrgKdeCantorRInterface
 */

OrgKdeCantorRInterface::OrgKdeCantorRInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgKdeCantorRInterface::~OrgKdeCantorRInterface()
{
}


#include "rserver_interface.moc"
