#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'standardsearchbar.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STANDARDSEARCHBAR_H
#define UI_STANDARDSEARCHBAR_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include "klineedit.h"
#include "ksqueezedtextlabel.h"

QT_BEGIN_NAMESPACE

class Ui_StandardSearchBar
{
public:
    QHBoxLayout *horizontalLayout_2;
    QHBoxLayout *horizontalLayout;
    QToolButton *close;
    QLabel *label;
    KLineEdit *pattern;
    QPushButton *next;
    QPushButton *previous;
    QSpacerItem *horizontalSpacer;
    QCheckBox *matchCase;
    KSqueezedTextLabel *status;
    QToolButton *openExtended;

    void setupUi(QWidget *StandardSearchBar)
    {
        if (StandardSearchBar->objectName().isEmpty())
            StandardSearchBar->setObjectName(QStringLiteral("StandardSearchBar"));
        StandardSearchBar->resize(736, 34);
        horizontalLayout_2 = new QHBoxLayout(StandardSearchBar);
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        close = new QToolButton(StandardSearchBar);
        close->setObjectName(QStringLiteral("close"));
        close->setAutoRaise(true);

        horizontalLayout->addWidget(close);

        label = new QLabel(StandardSearchBar);
        label->setObjectName(QStringLiteral("label"));

        horizontalLayout->addWidget(label);

        pattern = new KLineEdit(StandardSearchBar);
        pattern->setObjectName(QStringLiteral("pattern"));

        horizontalLayout->addWidget(pattern);

        next = new QPushButton(StandardSearchBar);
        next->setObjectName(QStringLiteral("next"));

        horizontalLayout->addWidget(next);

        previous = new QPushButton(StandardSearchBar);
        previous->setObjectName(QStringLiteral("previous"));

        horizontalLayout->addWidget(previous);

        horizontalSpacer = new QSpacerItem(13, 13, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        matchCase = new QCheckBox(StandardSearchBar);
        matchCase->setObjectName(QStringLiteral("matchCase"));

        horizontalLayout->addWidget(matchCase);

        status = new KSqueezedTextLabel(StandardSearchBar);
        status->setObjectName(QStringLiteral("status"));
        status->setAlignment(Qt::AlignCenter);

        horizontalLayout->addWidget(status);

        openExtended = new QToolButton(StandardSearchBar);
        openExtended->setObjectName(QStringLiteral("openExtended"));
        openExtended->setAutoRaise(true);

        horizontalLayout->addWidget(openExtended);


        horizontalLayout_2->addLayout(horizontalLayout);

        QWidget::setTabOrder(pattern, next);
        QWidget::setTabOrder(next, previous);
        QWidget::setTabOrder(previous, matchCase);
        QWidget::setTabOrder(matchCase, openExtended);
        QWidget::setTabOrder(openExtended, close);

        retranslateUi(StandardSearchBar);

        QMetaObject::connectSlotsByName(StandardSearchBar);
    } // setupUi

    void retranslateUi(QWidget *StandardSearchBar)
    {
        StandardSearchBar->setWindowTitle(tr2i18n("SearchBar", Q_NULLPTR));
        close->setText(tr2i18n("...", Q_NULLPTR));
        label->setText(tr2i18n("Find:", Q_NULLPTR));
        next->setText(tr2i18n("&Next", Q_NULLPTR));
        previous->setText(tr2i18n("&Previous", Q_NULLPTR));
        matchCase->setText(tr2i18n("&Match case", Q_NULLPTR));
        openExtended->setText(tr2i18n("...", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class StandardSearchBar: public Ui_StandardSearchBar {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STANDARDSEARCHBAR_H

