/****************************************************************************
** Meta object code from reading C++ file 'completionobject.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/cantor-17.08.3/src/lib/completionobject.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'completionobject.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Cantor__CompletionObject_t {
    QByteArrayData data[15];
    char stringdata0[204];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Cantor__CompletionObject_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Cantor__CompletionObject_t qt_meta_stringdata_Cantor__CompletionObject = {
    {
QT_MOC_LITERAL(0, 0, 24), // "Cantor::CompletionObject"
QT_MOC_LITERAL(1, 25, 12), // "fetchingDone"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 16), // "fetchingTypeDone"
QT_MOC_LITERAL(4, 56, 14), // "IdentifierType"
QT_MOC_LITERAL(5, 71, 4), // "type"
QT_MOC_LITERAL(6, 76, 4), // "done"
QT_MOC_LITERAL(7, 81, 8), // "lineDone"
QT_MOC_LITERAL(8, 90, 4), // "line"
QT_MOC_LITERAL(9, 95, 5), // "index"
QT_MOC_LITERAL(10, 101, 16), // "fetchCompletions"
QT_MOC_LITERAL(11, 118, 19), // "fetchIdentifierType"
QT_MOC_LITERAL(12, 138, 14), // "findCompletion"
QT_MOC_LITERAL(13, 153, 20), // "completeLineWithType"
QT_MOC_LITERAL(14, 174, 29) // "handleParenCompletionWithType"

    },
    "Cantor::CompletionObject\0fetchingDone\0"
    "\0fetchingTypeDone\0IdentifierType\0type\0"
    "done\0lineDone\0line\0index\0fetchCompletions\0"
    "fetchIdentifierType\0findCompletion\0"
    "completeLineWithType\0handleParenCompletionWithType"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Cantor__CompletionObject[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    1,   60,    2, 0x06 /* Public */,
       6,    0,   63,    2, 0x06 /* Public */,
       7,    2,   64,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    0,   69,    2, 0x09 /* Protected */,
      11,    0,   70,    2, 0x09 /* Protected */,
      12,    0,   71,    2, 0x09 /* Protected */,
      13,    1,   72,    2, 0x09 /* Protected */,
      14,    1,   75,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    8,    9,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, 0x80000000 | 4,    5,

       0        // eod
};

void Cantor::CompletionObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CompletionObject *_t = static_cast<CompletionObject *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->fetchingDone(); break;
        case 1: _t->fetchingTypeDone((*reinterpret_cast< IdentifierType(*)>(_a[1]))); break;
        case 2: _t->done(); break;
        case 3: _t->lineDone((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->fetchCompletions(); break;
        case 5: _t->fetchIdentifierType(); break;
        case 6: _t->findCompletion(); break;
        case 7: _t->completeLineWithType((*reinterpret_cast< IdentifierType(*)>(_a[1]))); break;
        case 8: _t->handleParenCompletionWithType((*reinterpret_cast< IdentifierType(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (CompletionObject::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&CompletionObject::fetchingDone)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (CompletionObject::*_t)(IdentifierType );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&CompletionObject::fetchingTypeDone)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (CompletionObject::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&CompletionObject::done)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (CompletionObject::*_t)(QString , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&CompletionObject::lineDone)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject Cantor::CompletionObject::staticMetaObject = {
    { &KCompletion::staticMetaObject, qt_meta_stringdata_Cantor__CompletionObject.data,
      qt_meta_data_Cantor__CompletionObject,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Cantor::CompletionObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cantor::CompletionObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Cantor__CompletionObject.stringdata0))
        return static_cast<void*>(this);
    return KCompletion::qt_metacast(_clname);
}

int Cantor::CompletionObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KCompletion::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Cantor::CompletionObject::fetchingDone()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Cantor::CompletionObject::fetchingTypeDone(IdentifierType _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Cantor::CompletionObject::done()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Cantor::CompletionObject::lineDone(QString _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
