/****************************************************************************
** Meta object code from reading C++ file 'worksheettextitem.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/cantor-17.08.3/src/worksheettextitem.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'worksheettextitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_WorksheetTextItem_t {
    QByteArrayData data[36];
    char stringdata0[410];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_WorksheetTextItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_WorksheetTextItem_t qt_meta_stringdata_WorksheetTextItem = {
    {
QT_MOC_LITERAL(0, 0, 17), // "WorksheetTextItem"
QT_MOC_LITERAL(1, 18, 14), // "moveToPrevious"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 3), // "pos"
QT_MOC_LITERAL(4, 38, 6), // "xCoord"
QT_MOC_LITERAL(5, 45, 10), // "moveToNext"
QT_MOC_LITERAL(6, 56, 21), // "cursorPositionChanged"
QT_MOC_LITERAL(7, 78, 11), // "QTextCursor"
QT_MOC_LITERAL(8, 90, 13), // "receivedFocus"
QT_MOC_LITERAL(9, 104, 18), // "WorksheetTextItem*"
QT_MOC_LITERAL(10, 123, 10), // "tabPressed"
QT_MOC_LITERAL(11, 134, 14), // "backtabPressed"
QT_MOC_LITERAL(12, 149, 15), // "applyCompletion"
QT_MOC_LITERAL(13, 165, 11), // "doubleClick"
QT_MOC_LITERAL(14, 177, 7), // "execute"
QT_MOC_LITERAL(15, 185, 11), // "deleteEntry"
QT_MOC_LITERAL(16, 197, 11), // "sizeChanged"
QT_MOC_LITERAL(17, 209, 11), // "menuCreated"
QT_MOC_LITERAL(18, 221, 6), // "QMenu*"
QT_MOC_LITERAL(19, 228, 4), // "drag"
QT_MOC_LITERAL(20, 233, 13), // "undoAvailable"
QT_MOC_LITERAL(21, 247, 13), // "redoAvailable"
QT_MOC_LITERAL(22, 261, 12), // "cutAvailable"
QT_MOC_LITERAL(23, 274, 13), // "copyAvailable"
QT_MOC_LITERAL(24, 288, 14), // "pasteAvailable"
QT_MOC_LITERAL(25, 303, 9), // "insertTab"
QT_MOC_LITERAL(26, 313, 3), // "cut"
QT_MOC_LITERAL(27, 317, 4), // "copy"
QT_MOC_LITERAL(28, 322, 5), // "paste"
QT_MOC_LITERAL(29, 328, 4), // "undo"
QT_MOC_LITERAL(30, 333, 4), // "redo"
QT_MOC_LITERAL(31, 338, 16), // "clipboardChanged"
QT_MOC_LITERAL(32, 355, 16), // "selectionChanged"
QT_MOC_LITERAL(33, 372, 8), // "testSize"
QT_MOC_LITERAL(34, 381, 21), // "updateRichTextActions"
QT_MOC_LITERAL(35, 403, 6) // "cursor"

    },
    "WorksheetTextItem\0moveToPrevious\0\0pos\0"
    "xCoord\0moveToNext\0cursorPositionChanged\0"
    "QTextCursor\0receivedFocus\0WorksheetTextItem*\0"
    "tabPressed\0backtabPressed\0applyCompletion\0"
    "doubleClick\0execute\0deleteEntry\0"
    "sizeChanged\0menuCreated\0QMenu*\0drag\0"
    "undoAvailable\0redoAvailable\0cutAvailable\0"
    "copyAvailable\0pasteAvailable\0insertTab\0"
    "cut\0copy\0paste\0undo\0redo\0clipboardChanged\0"
    "selectionChanged\0testSize\0"
    "updateRichTextActions\0cursor"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_WorksheetTextItem[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      28,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      18,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  154,    2, 0x06 /* Public */,
       5,    2,  159,    2, 0x06 /* Public */,
       6,    1,  164,    2, 0x06 /* Public */,
       8,    1,  167,    2, 0x06 /* Public */,
      10,    0,  170,    2, 0x06 /* Public */,
      11,    0,  171,    2, 0x06 /* Public */,
      12,    0,  172,    2, 0x06 /* Public */,
      13,    0,  173,    2, 0x06 /* Public */,
      14,    0,  174,    2, 0x06 /* Public */,
      15,    0,  175,    2, 0x06 /* Public */,
      16,    0,  176,    2, 0x06 /* Public */,
      17,    2,  177,    2, 0x06 /* Public */,
      19,    2,  182,    2, 0x06 /* Public */,
      20,    1,  187,    2, 0x06 /* Public */,
      21,    1,  190,    2, 0x06 /* Public */,
      22,    1,  193,    2, 0x06 /* Public */,
      23,    1,  196,    2, 0x06 /* Public */,
      24,    1,  199,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      25,    0,  202,    2, 0x0a /* Public */,
      26,    0,  203,    2, 0x0a /* Public */,
      27,    0,  204,    2, 0x0a /* Public */,
      28,    0,  205,    2, 0x0a /* Public */,
      29,    0,  206,    2, 0x0a /* Public */,
      30,    0,  207,    2, 0x0a /* Public */,
      31,    0,  208,    2, 0x0a /* Public */,
      32,    0,  209,    2, 0x0a /* Public */,
      33,    0,  210,    2, 0x08 /* Private */,
      34,    1,  211,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::QReal,    3,    4,
    QMetaType::Void, QMetaType::Int, QMetaType::QReal,    3,    4,
    QMetaType::Void, 0x80000000 | 7,    2,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 18, QMetaType::QPointF,    2,    2,
    QMetaType::Void, QMetaType::QPointF, QMetaType::QPointF,    2,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7,   35,

       0        // eod
};

void WorksheetTextItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        WorksheetTextItem *_t = static_cast<WorksheetTextItem *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->moveToPrevious((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 1: _t->moveToNext((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 2: _t->cursorPositionChanged((*reinterpret_cast< QTextCursor(*)>(_a[1]))); break;
        case 3: _t->receivedFocus((*reinterpret_cast< WorksheetTextItem*(*)>(_a[1]))); break;
        case 4: _t->tabPressed(); break;
        case 5: _t->backtabPressed(); break;
        case 6: _t->applyCompletion(); break;
        case 7: _t->doubleClick(); break;
        case 8: _t->execute(); break;
        case 9: _t->deleteEntry(); break;
        case 10: _t->sizeChanged(); break;
        case 11: _t->menuCreated((*reinterpret_cast< QMenu*(*)>(_a[1])),(*reinterpret_cast< const QPointF(*)>(_a[2]))); break;
        case 12: _t->drag((*reinterpret_cast< const QPointF(*)>(_a[1])),(*reinterpret_cast< const QPointF(*)>(_a[2]))); break;
        case 13: _t->undoAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->redoAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->cutAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->copyAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->pasteAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->insertTab(); break;
        case 19: _t->cut(); break;
        case 20: _t->copy(); break;
        case 21: _t->paste(); break;
        case 22: _t->undo(); break;
        case 23: _t->redo(); break;
        case 24: _t->clipboardChanged(); break;
        case 25: _t->selectionChanged(); break;
        case 26: _t->testSize(); break;
        case 27: _t->updateRichTextActions((*reinterpret_cast< QTextCursor(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< WorksheetTextItem* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QMenu* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (WorksheetTextItem::*_t)(int , qreal );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::moveToPrevious)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)(int , qreal );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::moveToNext)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)(QTextCursor );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::cursorPositionChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)(WorksheetTextItem * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::receivedFocus)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::tabPressed)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::backtabPressed)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::applyCompletion)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::doubleClick)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::execute)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::deleteEntry)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::sizeChanged)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)(QMenu * , const QPointF & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::menuCreated)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)(const QPointF & , const QPointF & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::drag)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::undoAvailable)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::redoAvailable)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::cutAvailable)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::copyAvailable)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (WorksheetTextItem::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WorksheetTextItem::pasteAvailable)) {
                *result = 17;
                return;
            }
        }
    }
}

const QMetaObject WorksheetTextItem::staticMetaObject = {
    { &QGraphicsTextItem::staticMetaObject, qt_meta_stringdata_WorksheetTextItem.data,
      qt_meta_data_WorksheetTextItem,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *WorksheetTextItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WorksheetTextItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_WorksheetTextItem.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsTextItem::qt_metacast(_clname);
}

int WorksheetTextItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsTextItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void WorksheetTextItem::moveToPrevious(int _t1, qreal _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void WorksheetTextItem::moveToNext(int _t1, qreal _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void WorksheetTextItem::cursorPositionChanged(QTextCursor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void WorksheetTextItem::receivedFocus(WorksheetTextItem * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void WorksheetTextItem::tabPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void WorksheetTextItem::backtabPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void WorksheetTextItem::applyCompletion()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void WorksheetTextItem::doubleClick()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void WorksheetTextItem::execute()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void WorksheetTextItem::deleteEntry()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void WorksheetTextItem::sizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void WorksheetTextItem::menuCreated(QMenu * _t1, const QPointF & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void WorksheetTextItem::drag(const QPointF & _t1, const QPointF & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void WorksheetTextItem::undoAvailable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void WorksheetTextItem::redoAvailable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void WorksheetTextItem::cutAvailable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void WorksheetTextItem::copyAvailable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void WorksheetTextItem::pasteAvailable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
