/****************************************************************************
** Meta object code from reading C++ file 'cantor_part.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/cantor-17.08.3/src/cantor_part.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cantor_part.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CantorPart_t {
    QByteArrayData data[44];
    char stringdata0[579];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CantorPart_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CantorPart_t qt_meta_stringdata_CantorPart = {
    {
QT_MOC_LITERAL(0, 0, 10), // "CantorPart"
QT_MOC_LITERAL(1, 11, 10), // "setCaption"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 7), // "caption"
QT_MOC_LITERAL(4, 31, 8), // "showHelp"
QT_MOC_LITERAL(5, 40, 4), // "help"
QT_MOC_LITERAL(6, 45, 10), // "fileSaveAs"
QT_MOC_LITERAL(7, 56, 13), // "fileSavePlain"
QT_MOC_LITERAL(8, 70, 13), // "exportToLatex"
QT_MOC_LITERAL(9, 84, 19), // "evaluateOrInterrupt"
QT_MOC_LITERAL(10, 104, 14), // "restartBackend"
QT_MOC_LITERAL(11, 119, 17), // "enableTypesetting"
QT_MOC_LITERAL(12, 137, 6), // "enable"
QT_MOC_LITERAL(13, 144, 15), // "showBackendHelp"
QT_MOC_LITERAL(14, 160, 5), // "print"
QT_MOC_LITERAL(15, 166, 12), // "printPreview"
QT_MOC_LITERAL(16, 179, 22), // "worksheetStatusChanged"
QT_MOC_LITERAL(17, 202, 23), // "Cantor::Session::Status"
QT_MOC_LITERAL(18, 226, 6), // "stauts"
QT_MOC_LITERAL(19, 233, 16), // "showSessionError"
QT_MOC_LITERAL(20, 250, 5), // "error"
QT_MOC_LITERAL(21, 256, 23), // "worksheetSessionChanged"
QT_MOC_LITERAL(22, 280, 11), // "initialized"
QT_MOC_LITERAL(23, 292, 13), // "updateCaption"
QT_MOC_LITERAL(24, 306, 14), // "pluginsChanged"
QT_MOC_LITERAL(25, 321, 10), // "runCommand"
QT_MOC_LITERAL(26, 332, 5), // "value"
QT_MOC_LITERAL(27, 338, 12), // "runAssistant"
QT_MOC_LITERAL(28, 351, 16), // "publishWorksheet"
QT_MOC_LITERAL(29, 368, 16), // "showScriptEditor"
QT_MOC_LITERAL(30, 385, 4), // "show"
QT_MOC_LITERAL(31, 390, 18), // "scriptEditorClosed"
QT_MOC_LITERAL(32, 409, 9), // "runScript"
QT_MOC_LITERAL(33, 419, 4), // "file"
QT_MOC_LITERAL(34, 424, 13), // "showSearchBar"
QT_MOC_LITERAL(35, 438, 21), // "showExtendedSearchBar"
QT_MOC_LITERAL(36, 460, 8), // "findNext"
QT_MOC_LITERAL(37, 469, 8), // "findPrev"
QT_MOC_LITERAL(38, 478, 16), // "searchBarDeleted"
QT_MOC_LITERAL(39, 495, 16), // "setStatusMessage"
QT_MOC_LITERAL(40, 512, 7), // "message"
QT_MOC_LITERAL(41, 520, 26), // "showImportantStatusMessage"
QT_MOC_LITERAL(42, 547, 14), // "blockStatusBar"
QT_MOC_LITERAL(43, 562, 16) // "unblockStatusBar"

    },
    "CantorPart\0setCaption\0\0caption\0showHelp\0"
    "help\0fileSaveAs\0fileSavePlain\0"
    "exportToLatex\0evaluateOrInterrupt\0"
    "restartBackend\0enableTypesetting\0"
    "enable\0showBackendHelp\0print\0printPreview\0"
    "worksheetStatusChanged\0Cantor::Session::Status\0"
    "stauts\0showSessionError\0error\0"
    "worksheetSessionChanged\0initialized\0"
    "updateCaption\0pluginsChanged\0runCommand\0"
    "value\0runAssistant\0publishWorksheet\0"
    "showScriptEditor\0show\0scriptEditorClosed\0"
    "runScript\0file\0showSearchBar\0"
    "showExtendedSearchBar\0findNext\0findPrev\0"
    "searchBarDeleted\0setStatusMessage\0"
    "message\0showImportantStatusMessage\0"
    "blockStatusBar\0unblockStatusBar"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CantorPart[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      32,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  174,    2, 0x06 /* Public */,
       4,    1,  177,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,  180,    2, 0x09 /* Protected */,
       7,    0,  181,    2, 0x09 /* Protected */,
       8,    0,  182,    2, 0x09 /* Protected */,
       9,    0,  183,    2, 0x09 /* Protected */,
      10,    0,  184,    2, 0x09 /* Protected */,
      11,    1,  185,    2, 0x09 /* Protected */,
      13,    0,  188,    2, 0x09 /* Protected */,
      14,    0,  189,    2, 0x09 /* Protected */,
      15,    0,  190,    2, 0x09 /* Protected */,
      16,    1,  191,    2, 0x09 /* Protected */,
      19,    1,  194,    2, 0x09 /* Protected */,
      21,    0,  197,    2, 0x09 /* Protected */,
      22,    0,  198,    2, 0x09 /* Protected */,
      23,    0,  199,    2, 0x09 /* Protected */,
      24,    0,  200,    2, 0x09 /* Protected */,
      25,    1,  201,    2, 0x09 /* Protected */,
      27,    0,  204,    2, 0x09 /* Protected */,
      28,    0,  205,    2, 0x09 /* Protected */,
      29,    1,  206,    2, 0x09 /* Protected */,
      31,    0,  209,    2, 0x09 /* Protected */,
      32,    1,  210,    2, 0x09 /* Protected */,
      34,    0,  213,    2, 0x09 /* Protected */,
      35,    0,  214,    2, 0x09 /* Protected */,
      36,    0,  215,    2, 0x09 /* Protected */,
      37,    0,  216,    2, 0x09 /* Protected */,
      38,    0,  217,    2, 0x09 /* Protected */,
      39,    1,  218,    2, 0x09 /* Protected */,
      41,    1,  221,    2, 0x09 /* Protected */,
      42,    0,  224,    2, 0x09 /* Protected */,
      43,    0,  225,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    5,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, QMetaType::QString,   20,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   26,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   33,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   40,
    QMetaType::Void, QMetaType::QString,   40,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void CantorPart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CantorPart *_t = static_cast<CantorPart *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setCaption((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->showHelp((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->fileSaveAs(); break;
        case 3: _t->fileSavePlain(); break;
        case 4: _t->exportToLatex(); break;
        case 5: _t->evaluateOrInterrupt(); break;
        case 6: _t->restartBackend(); break;
        case 7: _t->enableTypesetting((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->showBackendHelp(); break;
        case 9: _t->print(); break;
        case 10: _t->printPreview(); break;
        case 11: _t->worksheetStatusChanged((*reinterpret_cast< Cantor::Session::Status(*)>(_a[1]))); break;
        case 12: _t->showSessionError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->worksheetSessionChanged(); break;
        case 14: _t->initialized(); break;
        case 15: _t->updateCaption(); break;
        case 16: _t->pluginsChanged(); break;
        case 17: _t->runCommand((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 18: _t->runAssistant(); break;
        case 19: _t->publishWorksheet(); break;
        case 20: _t->showScriptEditor((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->scriptEditorClosed(); break;
        case 22: _t->runScript((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 23: _t->showSearchBar(); break;
        case 24: _t->showExtendedSearchBar(); break;
        case 25: _t->findNext(); break;
        case 26: _t->findPrev(); break;
        case 27: _t->searchBarDeleted(); break;
        case 28: _t->setStatusMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 29: _t->showImportantStatusMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 30: _t->blockStatusBar(); break;
        case 31: _t->unblockStatusBar(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (CantorPart::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&CantorPart::setCaption)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (CantorPart::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&CantorPart::showHelp)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject CantorPart::staticMetaObject = {
    { &KParts::ReadWritePart::staticMetaObject, qt_meta_stringdata_CantorPart.data,
      qt_meta_data_CantorPart,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *CantorPart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CantorPart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CantorPart.stringdata0))
        return static_cast<void*>(this);
    return KParts::ReadWritePart::qt_metacast(_clname);
}

int CantorPart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadWritePart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void CantorPart::setCaption(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void CantorPart::showHelp(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
