/****************************************************************************
** Meta object code from reading C++ file 'commandentry.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/cantor-17.08.3/src/commandentry.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'commandentry.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CommandEntry_t {
    QByteArrayData data[39];
    char stringdata0[532];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CommandEntry_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CommandEntry_t qt_meta_stringdata_CommandEntry = {
    {
QT_MOC_LITERAL(0, 0, 12), // "CommandEntry"
QT_MOC_LITERAL(1, 13, 19), // "evaluateCurrentItem"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 8), // "evaluate"
QT_MOC_LITERAL(4, 43, 16), // "EvaluationOption"
QT_MOC_LITERAL(5, 60, 6), // "evalOp"
QT_MOC_LITERAL(6, 67, 14), // "addInformation"
QT_MOC_LITERAL(7, 82, 12), // "removeResult"
QT_MOC_LITERAL(8, 95, 14), // "showCompletion"
QT_MOC_LITERAL(9, 110, 24), // "selectPreviousCompletion"
QT_MOC_LITERAL(10, 135, 11), // "updateEntry"
QT_MOC_LITERAL(11, 147, 12), // "updatePrompt"
QT_MOC_LITERAL(12, 160, 23), // "expressionChangedStatus"
QT_MOC_LITERAL(13, 184, 26), // "Cantor::Expression::Status"
QT_MOC_LITERAL(14, 211, 6), // "status"
QT_MOC_LITERAL(15, 218, 31), // "showAdditionalInformationPrompt"
QT_MOC_LITERAL(16, 250, 8), // "question"
QT_MOC_LITERAL(17, 259, 15), // "showCompletions"
QT_MOC_LITERAL(18, 275, 23), // "applySelectedCompletion"
QT_MOC_LITERAL(19, 299, 20), // "completedLineChanged"
QT_MOC_LITERAL(20, 320, 14), // "showSyntaxHelp"
QT_MOC_LITERAL(21, 335, 14), // "completeLineTo"
QT_MOC_LITERAL(22, 350, 4), // "line"
QT_MOC_LITERAL(23, 355, 5), // "index"
QT_MOC_LITERAL(24, 361, 13), // "startRemoving"
QT_MOC_LITERAL(25, 375, 14), // "moveToNextItem"
QT_MOC_LITERAL(26, 390, 3), // "pos"
QT_MOC_LITERAL(27, 394, 1), // "x"
QT_MOC_LITERAL(28, 396, 18), // "moveToPreviousItem"
QT_MOC_LITERAL(29, 415, 12), // "populateMenu"
QT_MOC_LITERAL(30, 428, 6), // "QMenu*"
QT_MOC_LITERAL(31, 435, 4), // "menu"
QT_MOC_LITERAL(32, 440, 10), // "invalidate"
QT_MOC_LITERAL(33, 451, 13), // "resultDeleted"
QT_MOC_LITERAL(34, 465, 17), // "updateCompletions"
QT_MOC_LITERAL(35, 483, 17), // "completeCommandTo"
QT_MOC_LITERAL(36, 501, 10), // "completion"
QT_MOC_LITERAL(37, 512, 14), // "CompletionMode"
QT_MOC_LITERAL(38, 527, 4) // "mode"

    },
    "CommandEntry\0evaluateCurrentItem\0\0"
    "evaluate\0EvaluationOption\0evalOp\0"
    "addInformation\0removeResult\0showCompletion\0"
    "selectPreviousCompletion\0updateEntry\0"
    "updatePrompt\0expressionChangedStatus\0"
    "Cantor::Expression::Status\0status\0"
    "showAdditionalInformationPrompt\0"
    "question\0showCompletions\0"
    "applySelectedCompletion\0completedLineChanged\0"
    "showSyntaxHelp\0completeLineTo\0line\0"
    "index\0startRemoving\0moveToNextItem\0"
    "pos\0x\0moveToPreviousItem\0populateMenu\0"
    "QMenu*\0menu\0invalidate\0resultDeleted\0"
    "updateCompletions\0completeCommandTo\0"
    "completion\0CompletionMode\0mode"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CommandEntry[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      25,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  139,    2, 0x0a /* Public */,
       3,    1,  140,    2, 0x0a /* Public */,
       3,    0,  143,    2, 0x2a /* Public | MethodCloned */,
       6,    0,  144,    2, 0x0a /* Public */,
       7,    0,  145,    2, 0x0a /* Public */,
       8,    0,  146,    2, 0x0a /* Public */,
       9,    0,  147,    2, 0x0a /* Public */,
      10,    0,  148,    2, 0x0a /* Public */,
      11,    0,  149,    2, 0x0a /* Public */,
      12,    1,  150,    2, 0x0a /* Public */,
      15,    1,  153,    2, 0x0a /* Public */,
      17,    0,  156,    2, 0x0a /* Public */,
      18,    0,  157,    2, 0x0a /* Public */,
      19,    0,  158,    2, 0x0a /* Public */,
      20,    0,  159,    2, 0x0a /* Public */,
      21,    2,  160,    2, 0x0a /* Public */,
      24,    0,  165,    2, 0x0a /* Public */,
      25,    2,  166,    2, 0x0a /* Public */,
      28,    2,  171,    2, 0x0a /* Public */,
      29,    2,  176,    2, 0x0a /* Public */,
      32,    0,  181,    2, 0x08 /* Private */,
      33,    0,  182,    2, 0x08 /* Private */,
      34,    0,  183,    2, 0x08 /* Private */,
      35,    2,  184,    2, 0x08 /* Private */,
      35,    1,  189,    2, 0x28 /* Private | MethodCloned */,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Bool, 0x80000000 | 4,    5,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,   22,   23,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QReal,   26,   27,
    QMetaType::Void, QMetaType::Int, QMetaType::QReal,   26,   27,
    QMetaType::Void, 0x80000000 | 30, QMetaType::QPointF,   31,   26,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 37,   36,   38,
    QMetaType::Void, QMetaType::QString,   36,

       0        // eod
};

void CommandEntry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CommandEntry *_t = static_cast<CommandEntry *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { bool _r = _t->evaluateCurrentItem();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->evaluate((*reinterpret_cast< EvaluationOption(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->evaluate();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->addInformation(); break;
        case 4: _t->removeResult(); break;
        case 5: _t->showCompletion(); break;
        case 6: _t->selectPreviousCompletion(); break;
        case 7: _t->updateEntry(); break;
        case 8: _t->updatePrompt(); break;
        case 9: _t->expressionChangedStatus((*reinterpret_cast< Cantor::Expression::Status(*)>(_a[1]))); break;
        case 10: _t->showAdditionalInformationPrompt((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->showCompletions(); break;
        case 12: _t->applySelectedCompletion(); break;
        case 13: _t->completedLineChanged(); break;
        case 14: _t->showSyntaxHelp(); break;
        case 15: _t->completeLineTo((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 16: _t->startRemoving(); break;
        case 17: _t->moveToNextItem((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 18: _t->moveToPreviousItem((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 19: _t->populateMenu((*reinterpret_cast< QMenu*(*)>(_a[1])),(*reinterpret_cast< const QPointF(*)>(_a[2]))); break;
        case 20: _t->invalidate(); break;
        case 21: _t->resultDeleted(); break;
        case 22: _t->updateCompletions(); break;
        case 23: _t->completeCommandTo((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< CompletionMode(*)>(_a[2]))); break;
        case 24: _t->completeCommandTo((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QMenu* >(); break;
            }
            break;
        }
    }
}

const QMetaObject CommandEntry::staticMetaObject = {
    { &WorksheetEntry::staticMetaObject, qt_meta_stringdata_CommandEntry.data,
      qt_meta_data_CommandEntry,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *CommandEntry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CommandEntry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CommandEntry.stringdata0))
        return static_cast<void*>(this);
    return WorksheetEntry::qt_metacast(_clname);
}

int CommandEntry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WorksheetEntry::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
