/****************************************************************************
** Meta object code from reading C++ file 'searchbar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/cantor-17.08.3/src/searchbar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'searchbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_SearchBar_t {
    QByteArrayData data[20];
    char stringdata0[328];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SearchBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SearchBar_t qt_meta_stringdata_SearchBar = {
    {
QT_MOC_LITERAL(0, 0, 9), // "SearchBar"
QT_MOC_LITERAL(1, 10, 16), // "on_close_clicked"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 23), // "on_openExtended_clicked"
QT_MOC_LITERAL(4, 52, 23), // "on_openStandard_clicked"
QT_MOC_LITERAL(5, 76, 15), // "on_next_clicked"
QT_MOC_LITERAL(6, 92, 19), // "on_previous_clicked"
QT_MOC_LITERAL(7, 112, 18), // "on_replace_clicked"
QT_MOC_LITERAL(8, 131, 21), // "on_replaceAll_clicked"
QT_MOC_LITERAL(9, 153, 22), // "on_pattern_textChanged"
QT_MOC_LITERAL(10, 176, 1), // "p"
QT_MOC_LITERAL(11, 178, 26), // "on_replacement_textChanged"
QT_MOC_LITERAL(12, 205, 1), // "r"
QT_MOC_LITERAL(13, 207, 18), // "on_addFlag_clicked"
QT_MOC_LITERAL(14, 226, 21), // "on_removeFlag_clicked"
QT_MOC_LITERAL(15, 248, 20), // "on_matchCase_toggled"
QT_MOC_LITERAL(16, 269, 1), // "b"
QT_MOC_LITERAL(17, 271, 21), // "invalidateStartCursor"
QT_MOC_LITERAL(18, 293, 23), // "invalidateCurrentCursor"
QT_MOC_LITERAL(19, 317, 10) // "toggleFlag"

    },
    "SearchBar\0on_close_clicked\0\0"
    "on_openExtended_clicked\0on_openStandard_clicked\0"
    "on_next_clicked\0on_previous_clicked\0"
    "on_replace_clicked\0on_replaceAll_clicked\0"
    "on_pattern_textChanged\0p\0"
    "on_replacement_textChanged\0r\0"
    "on_addFlag_clicked\0on_removeFlag_clicked\0"
    "on_matchCase_toggled\0b\0invalidateStartCursor\0"
    "invalidateCurrentCursor\0toggleFlag"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SearchBar[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   89,    2, 0x0a /* Public */,
       3,    0,   90,    2, 0x0a /* Public */,
       4,    0,   91,    2, 0x0a /* Public */,
       5,    0,   92,    2, 0x0a /* Public */,
       6,    0,   93,    2, 0x0a /* Public */,
       7,    0,   94,    2, 0x0a /* Public */,
       8,    0,   95,    2, 0x0a /* Public */,
       9,    1,   96,    2, 0x0a /* Public */,
      11,    1,   99,    2, 0x0a /* Public */,
      13,    0,  102,    2, 0x0a /* Public */,
      14,    0,  103,    2, 0x0a /* Public */,
      15,    1,  104,    2, 0x0a /* Public */,
      17,    0,  107,    2, 0x0a /* Public */,
      18,    0,  108,    2, 0x0a /* Public */,
      19,    0,  109,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void SearchBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SearchBar *_t = static_cast<SearchBar *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->on_close_clicked(); break;
        case 1: _t->on_openExtended_clicked(); break;
        case 2: _t->on_openStandard_clicked(); break;
        case 3: _t->on_next_clicked(); break;
        case 4: _t->on_previous_clicked(); break;
        case 5: _t->on_replace_clicked(); break;
        case 6: _t->on_replaceAll_clicked(); break;
        case 7: _t->on_pattern_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->on_replacement_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->on_addFlag_clicked(); break;
        case 10: _t->on_removeFlag_clicked(); break;
        case 11: _t->on_matchCase_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->invalidateStartCursor(); break;
        case 13: _t->invalidateCurrentCursor(); break;
        case 14: _t->toggleFlag(); break;
        default: ;
        }
    }
}

const QMetaObject SearchBar::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_SearchBar.data,
      qt_meta_data_SearchBar,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *SearchBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SearchBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SearchBar.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int SearchBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
